-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Loaded = 1 WHERE File = 'AnC_NewFlavors1_STOCK.sql';
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Vanilla
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- SpecialistFlavors
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM SpecialistFlavors;

INSERT INTO SpecialistFlavors (SpecialistType, FlavorType, Flavor)
SELECT AnC_Focus2SpecialistType.ST, AnC_Focus2SpecialistType.FT, sum(AnC_Focus2SpecialistType.Flavor) AS Flavor
FROM AnC_Focus2SpecialistType WHERE Flavor > 0
GROUP BY ST, FT;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Yield_Flavors
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM Yield_Flavors;

INSERT INTO Yield_Flavors (YieldType, FlavorType, Flavor)
SELECT YT, FT, sum(Flavor) AS Flavor
FROM AnC_Flavor2Yields, Yields 
WHERE AnC_Flavor2Yields.Flavor > 0 AND AnC_Flavor2Yields.YT = Yields.Type
GROUP BY YT, FT; 


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_Flavors
------------------------------------------------------------------------------------------------------------------------------------------------------
/* --> AnC_QueryViews
DELETE FROM Improvement_Flavors;

INSERT INTO Improvement_Flavors (ImprovementType, FlavorType, Flavor)
SELECT IT, FT, round(sum(AnC_Flavor2Improvement_Yields.Flavor)) AS Flavor
FROM AnC_Flavor2Improvement_Yields
GROUP BY IT, FT
ORDER BY IT;

DELETE FROM Improvement_Flavors WHERE Flavor <= 0;
*/


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Build_Flavors
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM Build_Flavors;

INSERT INTO Build_Flavors (BuildType, FlavorType, Flavor)
SELECT Builds.Type, Improvement_Flavors.FlavorType, Improvement_Flavors.Flavor
FROM Builds, Improvement_Flavors
WHERE Builds.ImprovementType = Improvement_Flavors.ImprovementType AND Improvement_Flavors.Flavor > 0
GROUP BY Builds.Type, Improvement_Flavors.FlavorType, Improvement_Flavors.ImprovementType
UNION ALL
--
SELECT Builds.Type, Flavors.Type, sum(100 - Routes.Movement) *Routes.Value *0.1
FROM Builds, Flavors, Routes
WHERE Builds.RouteType = Routes.Type
AND Flavors.Type IN ('FLAVOR_INFRASTRUCTURE')
GROUP BY Builds.Type, Flavors.Type
UNION ALL
--
SELECT Builds.Type, AnC_Flavor2Yields.FT, Route_Yields.Yield *AnC_Flavor2Yields.Flavor
FROM Builds, AnC_Flavor2Yields, Route_Yields
WHERE Route_Yields.Yield <> 0 AND Builds.RouteType = Route_Yields.RouteType
AND AnC_Flavor2Yields.YT = Route_Yields.YieldType;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Processes
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2Processes' ('FT' TEXT, 'PT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);

DELETE FROM 'AnC_Flavor2Processes';

INSERT INTO 'AnC_Flavor2Processes' (FT, PT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Process_ProductionYields
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Process_ProductionYields.ProcessType AS PT, sum(Process_ProductionYields.Yield *AnC_Flavor2Yields.Flavor) *0.1 AS Flavor,
'Process_ProductionYields' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Process_ProductionYields
WHERE /* we can also have negative Yields */ Process_ProductionYields.Yield <> 0 
AND AnC_Flavor2Yields.YT = Process_ProductionYields.YieldType
GROUP BY FT, PT
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Processes END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2BuildingType
------------------------------------------------------------------------------------------------------------------------------------------------------
-- prepare new Building Flavor's - create and replace is done within AnC_QueryViews

DELETE FROM 'AnC_Flavor2BuildingType';

INSERT INTO 'AnC_Flavor2BuildingType' (FT, BT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Unit_BuildingClassRequireds
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE 
WHEN count(Unit_BuildingClassRequireds.UnitType) BETWEEN 1 AND 3 THEN 10
WHEN count(Unit_BuildingClassRequireds.UnitType) BETWEEN 4 AND 6 THEN 20
WHEN count(Unit_BuildingClassRequireds.UnitType) BETWEEN 7 AND 9 THEN 30
WHEN count(Unit_BuildingClassRequireds.UnitType) BETWEEN 10 AND 12 THEN 40
WHEN count(Unit_BuildingClassRequireds.UnitType) >= 13 THEN 50
END) *(SELECT CASE WHEN AnC_Flavor2UnitAITypes.FT = 'FLAVOR_ARCHAEOLOGY' THEN 5 ELSE 1 END) AS Flavor,
'Unit_BuildingClassRequireds' AS FromTable, 'Vanilla' AS Mod
FROM Unit_BuildingClassRequireds, Buildings, AnC_Flavor2UnitAITypes
WHERE Unit_BuildingClassRequireds.UnitType = AnC_Flavor2UnitAITypes.UT
AND Buildings.BuildingClass = Unit_BuildingClassRequireds.BuildingClassType
AND AnC_Flavor2UnitAITypes.FT NOT IN ('FLAVOR_INFRASTRUCTURE', 'FLAVOR_NAVAL_TILE_IMPROVEMENT', 'FLAVOR_TILE_IMPROVEMENT')
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Unit_ProductionModifierBuildings
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Unit_ProductionModifierBuildings.BuildingType AS BT, 
sum(Unit_ProductionModifierBuildings.ProductionModifier) /count(Unit_ProductionModifierBuildings.UnitType) *2 AS Flavor,
'Unit_ProductionModifierBuildings' AS FromTable, 'Vanilla' AS Mod
FROM Unit_ProductionModifierBuildings, AnC_Flavor2UnitAITypes
WHERE (Unit_ProductionModifierBuildings.UnitType = AnC_Flavor2UnitAITypes.UT) 
OR (AnC_Flavor2UnitAITypes.UT = 'UNIT_FAKE' AND Unit_ProductionModifierBuildings.UnitType IN (SELECT UT FROM AnC_AllUN WHERE MP = 1))
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_AreaYieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_AreaYieldModifiers.BuildingType AS BT, sum(Building_AreaYieldModifiers.Yield *AnC_Flavor2Yields.Flavor) *50 AS Flavor,
'Building_AreaYieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_AreaYieldModifiers
WHERE /* we can also have negative Yields */ Building_AreaYieldModifiers.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_AreaYieldModifiers.YieldType
GROUP BY FT, Building_AreaYieldModifiers.BuildingType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_DomainFreeExperiences
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_DomainFreeExperiences.BuildingType AS BT, Building_DomainFreeExperiences.Experience 
	*(SELECT CASE WHEN AnC_Flavor2UnitAITypes.FT = 'FLAVOR_AIR' AND Building_DomainFreeExperiences.BuildingType = 'BUILDING_NAVAL_OFFICER_ACADEMY' THEN 0.4 
	WHEN AnC_Flavor2UnitAITypes.FT = 'FLAVOR_MILITARY_TRAINING' THEN 2 ELSE 1.5 END) AS Flavor,
'Building_DomainFreeExperiences' AS FromTable, 'Vanilla' AS Mod
FROM Building_DomainFreeExperiences, AnC_Flavor2UnitAITypes
WHERE AnC_Flavor2UnitAITypes.CC NOT NULL
AND AnC_Flavor2UnitAITypes.FT NOT IN ('FLAVOR_ARCHAEOLOGY', 'FLAVOR_CITY_DEFENSE', 'FLAVOR_DIPLOMACY', 'FLAVOR_INFRASTRUCTURE', 'FLAVOR_NAVAL_TILE_IMPROVEMENT', 'FLAVOR_NUKE', 'FLAVOR_PRODUCTION', 'FLAVOR_TILE_IMPROVEMENT')
AND Building_DomainFreeExperiences.DomainType = AnC_Flavor2UnitAITypes.Domain
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_DomainProductionModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_DomainProductionModifiers.BuildingType AS BT, Building_DomainProductionModifiers.Modifier *3 AS Flavor,
'Building_DomainProductionModifiers' AS FromTable, 'Vanilla' AS Mod
FROM Building_DomainProductionModifiers, AnC_Flavor2UnitAITypes
WHERE Building_DomainProductionModifiers.Modifier > 0 AND Building_DomainProductionModifiers.DomainType = AnC_Flavor2UnitAITypes.Domain 
AND AnC_Flavor2UnitAITypes.MP = 1 AND AnC_Flavor2UnitAITypes.FT NOT IN ('FLAVOR_NAVAL_TILE_IMPROVEMENT', 'FLAVOR_TILE_IMPROVEMENT')
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_FeatureYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_FeatureYieldChanges.BuildingType AS BT, sum(Building_FeatureYieldChanges.Yield *AnC_Flavor2Yields.Flavor) AS Flavor,
'Building_FeatureYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_FeatureYieldChanges
WHERE /* we just count positive Yields */ Building_FeatureYieldChanges.Yield > 0 
AND AnC_Flavor2Yields.YT = Building_FeatureYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
-- negative Yields have no impact as positive
/*SELECT AnC_Flavor2Yields.FT AS FT, Building_FeatureYieldChanges.BuildingType AS BT, sum(Building_FeatureYieldChanges.Yield *AnC_Flavor2Yields.Flavor) *0.5 AS Flavor,
'Building_FeatureYieldChanges' AS FromTable
FROM AnC_Flavor2Yields, Building_FeatureYieldChanges
WHERE*/ /* we can also have negative Yields */ /*Building_FeatureYieldChanges.Yield < 0 
AND AnC_Flavor2Yields.YT = Building_FeatureYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL*/
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_FreeSpecialistCounts
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Focus2SpecialistType.FT AS FT, Building_FreeSpecialistCounts.BuildingType AS BT, sum(Building_FreeSpecialistCounts.Count *AnC_Focus2SpecialistType.Flavor) AS Flavor,
'Building_FreeSpecialistCounts (Count)' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Focus2SpecialistType, Building_FreeSpecialistCounts
WHERE Building_FreeSpecialistCounts.Count > 0 AND Building_FreeSpecialistCounts.SpecialistType = AnC_Focus2SpecialistType.ST
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_FreeUnits
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Building_FreeUnits.FT AS FT, AnC_Flavor2Building_FreeUnits.BT AS BT, sum(AnC_Flavor2Building_FreeUnits.Flavor) *AnC_Flavor2Building_FreeUnits.NumUnits AS Flavor,
'Building_FreeUnits' AS FromTable, 'AnC' AS Mod
FROM AnC_Flavor2Building_FreeUnits
Group BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_GlobalYieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_GlobalYieldModifiers.BuildingType AS BT, sum(Building_GlobalYieldModifiers.Yield *AnC_Flavor2Yields.Flavor) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GlobalXModifiers') AS Flavor,
'Building_GlobalYieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_GlobalYieldModifiers
WHERE /* we can also have negative Yields */ Building_GlobalYieldModifiers.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_GlobalYieldModifiers.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_HurryModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_HurryModifiers.BuildingType AS BT, 
(SELECT CASE WHEN Building_HurryModifiers.HurryCostModifier < 0 THEN abs(Building_HurryModifiers.HurryCostModifier) ELSE Building_HurryModifiers.HurryCostModifier *-1 END) 
*AnC_Flavor2Yields.Flavor AS Flavor, 'Building_HurryModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_HurryModifiers
WHERE /* negative is good - positive is bad */ Building_HurryModifiers.HurryCostModifier <> 0 
AND AnC_Flavor2Yields.YT = Building_HurryModifiers.HurryType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_LakePlotYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_LakePlotYieldChanges.BuildingType AS BT, sum(Building_LakePlotYieldChanges.Yield *AnC_Flavor2Yields.Flavor) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PlotXChangesLake') AS Flavor, 'Building_LakePlotYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_LakePlotYieldChanges
WHERE /* we can also have negative Yields */ Building_LakePlotYieldChanges.Yield <> 0 
AND (AnC_Flavor2Yields.YT = Building_LakePlotYieldChanges.YieldType
OR (AnC_Flavor2Yields.YT = 'PlotXChangesNAVAL_GROWTH' AND Building_LakePlotYieldChanges.YieldType = 'YIELD_FOOD')) 
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_ResourceCultureChanges - empty - Vanilla
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_ResourceQuantity - Building_ResourceQuantity ('Flavor4Happines', 'Flavor2Wonder')
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Resources.FT AS FT, Building_ResourceQuantity.BuildingType AS BT, sum(AnC_Flavor2Resources.Flavor) AS Flavor,
'Building_ResourceQuantity_AnC_Flavor2Resources' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Resources, Building_ResourceQuantity
WHERE AnC_Flavor2Resources.RT = Building_ResourceQuantity.ResourceType
AND AnC_Flavor2Resources.FromTable IN ('Flavor4Happines', 'Flavor2Wonder')
GROUP BY FT, BT, RT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_ResourceYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_ResourceYieldChanges.BuildingType AS BT, sum(Building_ResourceYieldChanges.Yield *AnC_Flavor2Yields.Flavor) *0.5 AS Flavor,
'Building_ResourceYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_ResourceYieldChanges
WHERE /* we can also have negative Yields */ Building_ResourceYieldChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_ResourceYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_ResourceYieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_ResourceYieldModifiers.BuildingType AS BT, sum(Building_ResourceYieldModifiers.Yield *AnC_Flavor2Yields.Flavor) *0.5 AS Flavor,
'Building_ResourceYieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_ResourceYieldModifiers
WHERE /* we can also have negative Yields */ Building_ResourceYieldModifiers.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_ResourceYieldModifiers.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_RiverPlotYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_RiverPlotYieldChanges.BuildingType AS BT, sum(Building_RiverPlotYieldChanges.Yield *AnC_Flavor2Yields.Flavor) 
*(SELECT CASE WHEN AnC_Flavor2Yields.YT = 'YIELD_PRODUCTION' THEN 2 ELSE 1 END) *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PlotXChangesRiver') AS Flavor,
'Building_RiverPlotYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_RiverPlotYieldChanges
WHERE /* we can also have negative Yields */ Building_RiverPlotYieldChanges.Yield <> 0 
AND (AnC_Flavor2Yields.YT = Building_RiverPlotYieldChanges.YieldType
OR (AnC_Flavor2Yields.YT = 'PlotXChangesNAVAL_GROWTH' AND Building_RiverPlotYieldChanges.YieldType = 'YIELD_FOOD'))
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_SeaPlotYieldChanges 
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_SeaPlotYieldChanges.BuildingType AS BT, sum(Building_SeaPlotYieldChanges.Yield *AnC_Flavor2Yields.Flavor) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PlotXChangesSea') AS Flavor, 'Building_SeaPlotYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_SeaPlotYieldChanges
WHERE /* we can also have negative Yields */ Building_SeaPlotYieldChanges.Yield <> 0 
AND (AnC_Flavor2Yields.YT = Building_SeaPlotYieldChanges.YieldType
OR (AnC_Flavor2Yields.YT = 'PlotXChangesNAVAL_GROWTH' AND Building_SeaPlotYieldChanges.YieldType = 'YIELD_FOOD'))
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_SeaResourceYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_SeaResourceYieldChanges.BuildingType AS BT, sum(Building_SeaResourceYieldChanges.Yield *AnC_Flavor2Yields.Flavor) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'SeaResourceXChanges') AS Flavor,
'Building_SeaResourceYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_SeaResourceYieldChanges
WHERE /* we can also have negative Yields, just while we become an bonus in another table... so we just count pos */ Building_SeaResourceYieldChanges.Yield > 0 
AND AnC_Flavor2Yields.YT IN (Building_SeaResourceYieldChanges.YieldType, 'SeaResourceXChanges')
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_SpecialistYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_SpecialistYieldChanges.BuildingType AS BT, sum(Building_SpecialistYieldChanges.Yield *AnC_Flavor2Yields.Flavor) AS Flavor,
'Building_SpecialistYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_SpecialistYieldChanges
WHERE /* we can also have negative Yields */ Building_SpecialistYieldChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_SpecialistYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_TechEnhancedYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Instant
SELECT AnC_Flavor2Yields.FT AS FT, Building_TechEnhancedYieldChanges.BuildingType AS BT, Building_TechEnhancedYieldChanges.Yield *AnC_Flavor2Yields.Flavor AS Flavor,
'Building_TechEnhancedYieldChanges_Instant' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_TechEnhancedYieldChanges, Buildings
WHERE /* we can also have negative Yields */ Building_TechEnhancedYieldChanges.Yield <> 0 
AND Building_TechEnhancedYieldChanges.BuildingType = Buildings.Type
AND Buildings.EnhancedYieldTech = Buildings.PrereqTech
AND AnC_Flavor2Yields.YT = Building_TechEnhancedYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
-- Later
SELECT AnC_Flavor2Yields.FT AS FT, Building_TechEnhancedYieldChanges.BuildingType AS BT, round(Building_TechEnhancedYieldChanges.Yield *AnC_Flavor2Yields.Flavor *0.5,2) AS Flavor,
'Building_TechEnhancedYieldChanges_Later' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_TechEnhancedYieldChanges, Buildings
WHERE /* we can also have negative Yields */ Building_TechEnhancedYieldChanges.Yield <> 0 
AND Building_TechEnhancedYieldChanges.BuildingType = Buildings.Type
AND AnC_Flavor2Yields.YT = Building_TechEnhancedYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_TerrainYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_TerrainYieldChanges.BuildingType AS BT, Building_TerrainYieldChanges.Yield *AnC_Flavor2Yields.Flavor *2 AS Flavor,
'Building_TerrainYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_TerrainYieldChanges
WHERE /* we can also have negative Yields */ Building_TerrainYieldChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_TerrainYieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_UnitCombatFreeExperiences /2
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_UnitCombatFreeExperiences.BuildingType AS BT, Building_UnitCombatFreeExperiences.Experience *0.5 AS Flavor,
AnC_JustUUaUB.FromTable AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Building_UnitCombatFreeExperiences, AnC_JustUUaUB
WHERE AnC_JustUUaUB.CC = Building_UnitCombatFreeExperiences.UnitCombatType
AND AnC_JustUUaUB.BT = Building_UnitCombatFreeExperiences.BuildingType
AND AnC_JustUUaUB.FromTable = 'Building_UnitCombatFreeExperiences'
AND AnC_Flavor2UnitAITypes.UT = AnC_JustUUaUB.UT
GROUP BY FT, BT
UNION ALL
--
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_UnitCombatFreeExperiences.BuildingType AS BT, Building_UnitCombatFreeExperiences.Experience *0.5 AS Flavor,
'Building_UnitCombatFreeExperiences' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Building_UnitCombatFreeExperiences
WHERE (AnC_Flavor2UnitAITypes.CC = Building_UnitCombatFreeExperiences.UnitCombatType OR AnC_Flavor2UnitAITypes.CC = 'UNITCOMBAT_FAKE')
AND (AnC_Flavor2UnitAITypes.UT NOT IN (SELECT UT FROM AnC_JustUUaUB)
AND Building_UnitCombatFreeExperiences.BuildingType NOT IN (SELECT BT FROM AnC_JustUUaUB))
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_UnitCombatProductionModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_UnitCombatProductionModifiers.BuildingType AS BT, Building_UnitCombatProductionModifiers.Modifier *2 AS Flavor,
AnC_JustUUaUB.FromTable AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Building_UnitCombatProductionModifiers, AnC_JustUUaUB
WHERE Building_UnitCombatProductionModifiers.Modifier <> 0
AND AnC_JustUUaUB.CC = Building_UnitCombatProductionModifiers.UnitCombatType 
AND AnC_JustUUaUB.BT = Building_UnitCombatProductionModifiers.BuildingType
AND AnC_JustUUaUB.FromTable = 'Building_UnitCombatProductionModifiersUU2UB'
AND AnC_Flavor2UnitAITypes.UT = AnC_JustUUaUB.UT
GROUP BY FT, BT
UNION ALL
--
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_UnitCombatProductionModifiers.BuildingType AS BT, Building_UnitCombatProductionModifiers.Modifier *2 AS Flavor,
'Building_UnitCombatProductionModifiersUn2Bu' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Building_UnitCombatProductionModifiers, AnC_JustUUaUB
WHERE Building_UnitCombatProductionModifiers.Modifier <> 0
AND AnC_Flavor2UnitAITypes.CC = 'UNITCOMBAT_FAKE'
AND Building_UnitCombatProductionModifiers.BuildingType = AnC_JustUUaUB.BT
GROUP BY FT, BT
UNION ALL
--
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Building_UnitCombatProductionModifiers.BuildingType AS BT, Building_UnitCombatProductionModifiers.Modifier *2 AS Flavor,
'Building_UnitCombatProductionModifiersUn2Bu' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Building_UnitCombatProductionModifiers
WHERE Building_UnitCombatProductionModifiers.Modifier <> 0
AND ((AnC_Flavor2UnitAITypes.CC = Building_UnitCombatProductionModifiers.UnitCombatType AND AnC_Flavor2UnitAITypes.MP = 1) OR AnC_Flavor2UnitAITypes.CC = 'UNITCOMBAT_FAKE')
AND (AnC_Flavor2UnitAITypes.UT NOT IN (SELECT UT FROM AnC_JustUUaUB)
AND Building_UnitCombatProductionModifiers.BuildingType NOT IN (SELECT BT FROM AnC_JustUUaUB))
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_YieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_YieldChanges.BuildingType AS BT, sum(Building_YieldChanges.Yield *AnC_Flavor2Yields.Flavor) AS Flavor,
'Building_YieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_YieldChanges
WHERE /* we can also have negative Yields */ Building_YieldChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_YieldChanges.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_YieldChangesPerPop
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_YieldChangesPerPop.BuildingType AS BT, sum(Building_YieldChangesPerPop.Yield) AS Flavor,
'Building_YieldChangesPerPop' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_YieldChangesPerPop
WHERE /* we can also have negative Yields */ Building_YieldChangesPerPop.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_YieldChangesPerPop.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Building_YieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Building_YieldModifiers.BuildingType AS BT, sum(Building_YieldModifiers.Yield *AnC_Flavor2Yields.Flavor) *0.1 AS Flavor,
'Building_YieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Building_YieldModifiers
WHERE /* we can also have negative Yields */ Building_YieldModifiers.Yield <> 0 
AND AnC_Flavor2Yields.YT = Building_YieldModifiers.YieldType
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.AirModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.AirModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.AirModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.AirModifier >= 1 AND AnC_Flavor2Yields.YT = 'AirModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
--Buildings.UnitUpgradeCostMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, abs(Buildings.UnitUpgradeCostMod) *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.UnitUpgradeCostMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.UnitUpgradeCostMod < 0 AND AnC_Flavor2Yields.YT = 'UnitUpgradeCostMod'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.SpecialistType (Count) 
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Focus2SpecialistType.FT AS FT, Buildings.Type AS BT, sum(Buildings.SpecialistCount *AnC_Focus2SpecialistType.Flavor) AS Flavor,
'Buildings.SpecialistType (Count)' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Focus2SpecialistType, Buildings
WHERE Buildings.SpecialistCount > 0 AND Buildings.SpecialistType = AnC_Focus2SpecialistType.ST
GROUP BY FT, BT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.Airlift
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.Airlift *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.Airlift' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.Airlift >= 1 AND AnC_Flavor2Yields.YT = 'Airlift'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.HealRateChange
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.HealRateChange *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.HealRateChange' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.HealRateChange >= 1 AND AnC_Flavor2Yields.YT = 'HealRateChange'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.NukeModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, abs(Buildings.NukeModifier) *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.NukeModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.NukeModifier < 0 AND AnC_Flavor2Yields.YT = 'NukeModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.AllowsRangeStrike
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.AllowsRangeStrike *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.AllowsRangeStrike' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.AllowsRangeStrike = 1 AND AnC_Flavor2Yields.YT = 'AllowsRangeStrike'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.Defense
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.Defense *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.Defense' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.Defense >= 1 AND AnC_Flavor2Yields.YT = 'Defense'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GlobalDefenseMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GlobalDefenseMod *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.GlobalDefenseMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.GlobalDefenseMod >= 1 AND AnC_Flavor2Yields.YT = 'GlobalDefenseMod'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.ExtraCityHitPoints
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.ExtraCityHitPoints *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.ExtraCityHitPoints' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.ExtraCityHitPoints >= 1 AND AnC_Flavor2Yields.YT = 'ExtraCityHitPoints'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.BorderObstacle
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.BorderObstacle *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.BorderObstacle' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.BorderObstacle = 1 AND AnC_Flavor2Yields.YT = 'BorderObstacle'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.CultureRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.CultureRateModifier *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CultureRateModifier') AS Flavor, 'Buildings.CultureRateModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.CultureRateModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GlobalCultureRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GlobalCultureRateModifier *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GlobalCultureRateModifier') AS Flavor, 'Buildings.GlobalCultureRateModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.GlobalCultureRateModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.PolicyCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE WHEN Buildings.PolicyCostModifier < 0 THEN abs(Buildings.PolicyCostModifier) ELSE Buildings.PolicyCostModifier *-1 END) 
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PolicyCostModifier') AS Flavor,
'Buildings.PolicyCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* negative is good - positive is bad */ Buildings.PolicyCostModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.FreePolicies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.FreePolicies *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'FreePolicies') AS Flavor, 'Buildings.FreePolicies' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.FreePolicies >= 1 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GreatPeopleRateChange
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Focus2SpecialistType.FT AS FT, Buildings.Type AS BT, Buildings.GreatPeopleRateChange *AnC_Focus2SpecialistType.Flavor AS Flavor,
'Buildings.GreatPeopleRateChange' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Focus2SpecialistType, Buildings
WHERE Buildings.GreatPeopleRateChange > 0 AND Buildings.SpecialistType = AnC_Focus2SpecialistType.ST
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GoldenAge
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GoldenAge *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GoldenAge') AS Flavor, 'Buildings.GoldenAge' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.GoldenAge = 1 AND AnC_Flavor2Yields.YT = 'YIELD_GOLDEN_AGE_POINTS'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GoldenAgeModifier 
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GoldenAgeModifier *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GoldenAgeModifier') AS Flavor, 'Buildings.GoldenAgeModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.GoldenAgeModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLDEN_AGE_POINTS'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.MilitaryProductionModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.MilitaryProductionModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.MilitaryProductionModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.MilitaryProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'MilitaryProductionModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.FreePromotion *30 -- create new based on real promotions?
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Flavors.Type AS FT, Buildings.Type AS BT, 1 *30 AS Flavor,
'Buildings.FreePromotion' AS FromTable, 'Vanilla' AS Mod
FROM Flavors, Buildings
WHERE Flavors.Type IN ('FLAVOR_DEFENSE', 'FLAVOR_OFFENSE', 'FLAVOR_MILITARY_TRAINING') AND Buildings.FreePromotion NOT NULL
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.TrainedFreePromotion *15 -- create new based on real promotions?
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Flavors.Type AS FT, Buildings.Type AS BT, 1 *15 AS Flavor,
'Buildings.TrainedFreePromotion' AS FromTable, 'Vanilla' AS Mod
FROM Flavors, Buildings
WHERE Flavors.Type IN ('FLAVOR_DEFENSE', 'FLAVOR_OFFENSE', 'FLAVOR_MILITARY_TRAINING') AND Buildings.TrainedFreePromotion NOT NULL
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.PlotCultureCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE WHEN Buildings.PlotCultureCostModifier < 0 THEN abs(Buildings.PlotCultureCostModifier) ELSE Buildings.PlotCultureCostModifier *-1 END)
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PlotCultureCostModifier') AS Flavor, 
'Buildings.PlotCultureCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* negative is good - positive is bad */ Buildings.PlotCultureCostModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GlobalPlotCultureCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE WHEN Buildings.GlobalPlotCultureCostModifier < 0 THEN abs(Buildings.GlobalPlotCultureCostModifier) ELSE Buildings.GlobalPlotCultureCostModifier *-1 END)
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GlobalPlotCultureCostModifier') AS Flavor, 
'Buildings.GlobalPlotCultureCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* negative is good - positive is bad */ Buildings.GlobalPlotCultureCostModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.PlotBuyCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE WHEN Buildings.PlotBuyCostModifier < 0 THEN abs(Buildings.PlotBuyCostModifier) ELSE Buildings.PlotBuyCostModifier *-1 END) 
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PlotBuyCostModifier') AS Flavor,
'Buildings.PlotBuyCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* negative is good - positive is bad */ Buildings.PlotBuyCostModifier <> 0 AND AnC_Flavor2Yields.YT IN ('PlotBuyCostModifier', 'YIELD_GOLD')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GlobalPlotBuyCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE WHEN Buildings.GlobalPlotBuyCostModifier < 0 THEN abs(Buildings.GlobalPlotBuyCostModifier) ELSE Buildings.GlobalPlotBuyCostModifier *-1 END)
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GlobalPlotBuyCostModifier') AS Flavor,
'Buildings.GlobalPlotBuyCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* negative is good - positive is bad */ Buildings.GlobalPlotBuyCostModifier <> 0 AND AnC_Flavor2Yields.YT IN ('GlobalPlotBuyCostModifier', 'YIELD_GOLD')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.ExtraLuxuries
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.ExtraLuxuries *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.ExtraLuxuries' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.ExtraLuxuries = 1 AND AnC_Flavor2Yields.YT IN ('ExtraLuxuries', 'YIELD_GOLD')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GreatPersonExpendGold
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GreatPersonExpendGold *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.GreatPersonExpendGold' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.GreatPersonExpendGold >= 1 AND AnC_Flavor2Yields.YT = 'GreatPersonExpendGold'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.CapturePlunderModifier 
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, 
(SELECT CASE WHEN Buildings.CapturePlunderModifier < 0 THEN abs(Buildings.CapturePlunderModifier) ELSE Buildings.CapturePlunderModifier *-0.1 END)
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CapturePlunderModifier') AS Flavor, 
'Buildings.CapturePlunderModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* negative is good - positive is bad */ Buildings.CapturePlunderModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GreatPeopleRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GreatPeopleRateModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.GreatPeopleRateModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.GreatPeopleRateModifier <> 0 AND AnC_Flavor2Yields.YT = 'GreatPeopleRateModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GlobalGreatPeopleRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GlobalGreatPeopleRateModifier *AnC_Flavor2Yields.Flavor *AnC_Flavor2Yields.TableMul AS Flavor,
'Buildings.GlobalGreatPeopleRateModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.GlobalGreatPeopleRateModifier <> 0 AND AnC_Flavor2Yields.YT = 'GlobalGreatPeopleRateModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.FreeGreatPeople
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.FreeGreatPeople *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.FreeGreatPeople' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.FreeGreatPeople > 0 AND AnC_Flavor2Yields.YT = 'FreeGreatPeople'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.FoodKept
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.FoodKept *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'FoodKept') AS Flavor,
'Buildings.FoodKept' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.FoodKept <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_FOOD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.GlobalPopulationChange
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.GlobalPopulationChange *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GlobalPopulationChange') AS Flavor,
'Buildings.GlobalPopulationChange' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.GlobalPopulationChange <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_POPULATION'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.Happiness
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.Happiness *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.Happiness' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.Happiness <> 0 AND AnC_Flavor2Yields.YT = 'Happiness'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.UnmoddedHappiness
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.UnmoddedHappiness *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.UnmoddedHappiness' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.UnmoddedHappiness <> 0 AND AnC_Flavor2Yields.YT = 'UnmoddedHappiness'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.HappinessPerCity
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.HappinessPerCity *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.HappinessPerCity' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.HappinessPerCity <> 0 AND AnC_Flavor2Yields.YT = 'HappinessPerCity'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.HappinessPerXPolicies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.HappinessPerXPolicies *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.HappinessPerXPolicies' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.HappinessPerXPolicies <> 0 AND AnC_Flavor2Yields.YT = 'HappinessPerXPolicies'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.NoOccupiedUnhappiness
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.NoOccupiedUnhappiness *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.NoOccupiedUnhappiness' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can just have 0/1 */ Buildings.NoOccupiedUnhappiness = 1 AND AnC_Flavor2Yields.YT = 'NoOccupiedUnhappiness'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.BuildingProductionModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.BuildingProductionModifier *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'BuildingProductionModifier') AS Flavor,
'Buildings.BuildingProductionModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.BuildingProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_PRODUCTION'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.WonderProductionModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.WonderProductionModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.WonderProductionModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.WonderProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'WonderProductionModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.FoundsReligion
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.FoundsReligion *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'FoundsReligion') AS Flavor, 'Buildings.FoundsReligion' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can just have 0/1 */ Buildings.FoundsReligion = 1 AND AnC_Flavor2Yields.YT = 'YIELD_FAITH'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.FreeTechs
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.FreeTechs *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'FreeTechs') AS Flavor, 'Buildings.FreeTechs' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can just have + */ Buildings.FreeTechs >= 1 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.MedianTechPercentChange
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.MedianTechPercentChange *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'MedianTechPercentChange') AS Flavor, 'Buildings.MedianTechPercentChange' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can also have negative Yields */ Buildings.MedianTechPercentChange <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.WorkerSpeedModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.WorkerSpeedModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.WorkerSpeedModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE Buildings.WorkerSpeedModifier >= 1 AND AnC_Flavor2Yields.YT = 'WorkerSpeedModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings.AllowsWaterRoutes (The AI already knows, that it's also good for Gold and Production?)
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Buildings.Type AS BT, Buildings.AllowsWaterRoutes *AnC_Flavor2Yields.Flavor AS Flavor,
'Buildings.AllowsWaterRoutes' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Buildings
WHERE /* we can just have 0/1 */ Buildings.AllowsWaterRoutes = 1 AND AnC_Flavor2Yields.YT IN ('AllowsWaterRoutes', 'YIELD_GOLD', 'YIELD_PRODUCTION')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- BuildingClasses
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Flavors.Type AS FT, BuildingClasses.DefaultBuilding AS BT, 30 AS Flavor,
'BuildingClasses.Wonder' AS FromTable, 'Vanilla' AS Mod
FROM Flavors, BuildingClasses
WHERE Flavors.Type IN ('FLAVOR_WONDER') AND BuildingClasses.MaxGlobalInstances >= 1 OR BuildingClasses.MaxTeamInstances >= 1
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2BuildingType END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Policies
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2Policies' ('FT' TEXT, 'PT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);

DELETE FROM AnC_Flavor2Policies;

INSERT INTO 'AnC_Flavor2Policies' (FT, PT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.PolicyCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.PolicyCostModifier < 0 THEN abs(Policies.PolicyCostModifier) ELSE Policies.PolicyCostModifier *-1 END)
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'PolicyCostModifier') AS Flavor, 'Policies.PolicyCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.PolicyCostModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CulturePerCity all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CulturePerWonder all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CultureWonderMultiplier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CulturePerTechResearched all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CultureImprovementChange all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CultureFromKills all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CultureFromKills *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CultureFromBarbarianKills') AS Flavor, 'Policies.CultureFromKills' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CultureFromKills <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CultureFromBarbarianKills
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CultureFromBarbarianKills *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CultureFromBarbarianKills') AS Flavor, 'Policies.CultureFromBarbarianKills' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CultureFromBarbarianKills <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldFromKills
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.GoldFromKills *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GoldFromKills') AS Flavor, 'Policies.GoldFromKills' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.GoldFromKills <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.EmbarkedExtraMoves
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.EmbarkedExtraMoves *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.EmbarkedExtraMoves' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.EmbarkedExtraMoves <> 0 AND AnC_Flavor2Yields.YT = 'EmbarkedExtraMoves'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.AttackBonusTurns
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.AttackBonusTurns *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.AttackBonusTurns' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.AttackBonusTurns > 0 AND AnC_Flavor2Yields.YT = 'AttackBonusTurns'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldenAgeTurns
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.GoldenAgeTurns *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.GoldenAgeTurns') AS Flavor,
'Policies.GoldenAgeTurns' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.GoldenAgeTurns <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLDEN_AGE_POINTS'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldenAgeMeterMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldenAgeDurationMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.GoldenAgeDurationMod *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.GoldenAgeDurationMod') AS Flavor,
'Policies.GoldenAgeDurationMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.GoldenAgeDurationMod <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLDEN_AGE_POINTS'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumFreeTechs
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.NumFreeTechs *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.NumFreeTechs') AS Flavor, 'Policies.NumFreeTechs' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.NumFreeTechs > 0 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumFreePolicies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.NumFreePolicies *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.NumFreePolicies') AS Flavor,
'Policies.NumFreePolicies' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.NumFreePolicies > 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumFreeGreatPeople
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.NumFreeGreatPeople *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.NumFreeGreatPeople' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.NumFreeGreatPeople > 0 AND AnC_Flavor2Yields.YT = 'Policies.NumFreeGreatPeople'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MedianTechPercentChange
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.MedianTechPercentChange *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'MedianTechPercentChange') AS Flavor, 'Policies.MedianTechPercentChange' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.MedianTechPercentChange <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.StrategicResourceMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Resources.FT AS FT, Policies.Type AS PT, Policies.StrategicResourceMod *sum(AnC_Flavor2Resources.Flavor) /count(AnC_Flavor2Resources.RT) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.StrategicResourceMod') AS Flavor,
'Policies.StrategicResourceMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Resources, Policies
WHERE /* we can also have negative Yields */ Policies.StrategicResourceMod <> 0 AND AnC_Flavor2Resources.RU = 1
GROUP BY AnC_Flavor2Resources.FT, Policies.Type
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.WonderProductionModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.WonderProductionModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.WonderProductionModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.WonderProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'WonderProductionModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.BuildingProductionModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.BuildingProductionModifier *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'BuildingProductionModifier') AS Flavor,
'Policies.BuildingProductionModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.BuildingProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_PRODUCTION'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GreatPeopleRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT DISTINCT AnC_Flavor2GreatPersons.FT AS FT, Policies.Type AS PT, round(Policies.GreatPeopleRateModifier *AnC_Flavor2Yields.Flavor
*(SELECT CASE WHEN AnC_Flavor2GreatPersons.FT NOT IN ('FLAVOR_GREAT_PEOPLE') THEN 0.25 ELSE 1 END)
*AnC_Flavor2Yields.TableMul,2) AS Flavor, 'Policies.GreatPeopleRateModifier' AS FromTable, 'BNW' AS Mod
FROM AnC_Flavor2GreatPersons, AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.GreatPeopleRateModifier <> 0 
AND AnC_Flavor2GreatPersons.UT IN ('UNIT_ARTIST', 'UNIT_ENGINEER', 'UNIT_MERCHANT', 'UNIT_MUSICIAN', 'UNIT_SCIENTIST', 'UNIT_WRITER')
AND AnC_Flavor2Yields.YT = 'Policies.GreatPeopleRateModifier'
GROUP BY AnC_Flavor2GreatPersons.FT, Policies.Type
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GreatGeneralRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2GreatPersons.FT AS FT, Policies.Type AS PT, Policies.GreatGeneralRateModifier *AnC_Flavor2Yields.Flavor 
*AnC_Flavor2Yields.TableMul AS Flavor, 'Policies.GreatGeneralRateModifier' AS FromTable, 'BNW' AS Mod
FROM AnC_Flavor2GreatPersons, AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.GreatGeneralRateModifier <> 0 AND AnC_Flavor2GreatPersons.UT = 'UNIT_GREAT_GENERAL'
AND AnC_Flavor2Yields.YT = 'Policies.GreatGeneralRateModifier'
GROUP BY AnC_Flavor2GreatPersons.FT, Policies.Type
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.DomesticGreatGeneralRateModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2GreatPersons.FT AS FT, Policies.Type AS PT, Policies.DomesticGreatGeneralRateModifier *AnC_Flavor2Yields.Flavor 
*AnC_Flavor2Yields.TableMul AS Flavor, 'Policies.DomesticGreatGeneralRateModifier' AS FromTable, 'BNW' AS Mod
FROM AnC_Flavor2GreatPersons, AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.DomesticGreatGeneralRateModifier <> 0 AND AnC_Flavor2GreatPersons.UT = 'UNIT_GREAT_GENERAL'
AND AnC_Flavor2Yields.YT = 'Policies.DomesticGreatGeneralRateModifier'
GROUP BY AnC_Flavor2GreatPersons.FT, Policies.Type
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ExtraHappiness
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.ExtraHappiness *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.ExtraHappiness' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.ExtraHappiness <> 0 AND AnC_Flavor2Yields.YT = 'Happiness' -- Happiness = ExtraHappiness
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ExtraHappinessPerCity
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.ExtraHappinessPerCity *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.ExtraHappinessPerCity' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.ExtraHappinessPerCity <> 0 AND AnC_Flavor2Yields.YT = 'HappinessPerCity' -- ExtraHappinessPerCity = HappinessPerCity
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnhappinessMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CityCountUnhappinessMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.OccupiedPopulationUnhappinessMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CapitalUnhappinessMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.FreeExperience
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.FreeExperience *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.FreeExperience' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.FreeExperience > 0 AND AnC_Flavor2Yields.YT = 'FreeExperience'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.WorkerSpeedModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.WorkerSpeedModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.WorkerSpeedModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.WorkerSpeedModifier <> 0 AND AnC_Flavor2Yields.YT = 'Policies.WorkerSpeedModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.AllFeatureProduction all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ImprovementCostModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ImprovementUpgradeRateModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.SpecialistProductionModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.SpecialistUpgradeModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MilitaryProductionModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.MilitaryProductionModifier *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.MilitaryProductionModifier') AS Flavor,
'Policies.MilitaryProductionModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.MilitaryProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'MilitaryProductionModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.BaseFreeUnits
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.BaseFreeUnits *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.BaseFreeUnits') AS Flavor,
'Policies.BaseFreeUnits' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.BaseFreeUnits <> 0 AND AnC_Flavor2Yields.YT IN ('Policies.BaseFreeUnits', 'YIELD_GOLD')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.BaseFreeMilitaryUnits all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.FreeUnitsPopulationPercent all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.FreeMilitaryUnitsPopulationPercent all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HappinessPerGarrisonedUnit
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.HappinessPerGarrisonedUnit *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.HappinessPerGarrisonedUnit' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.HappinessPerGarrisonedUnit <> 0 AND AnC_Flavor2Yields.YT = 'HappinessPerGarrisonedUnit'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CulturePerGarrisonedUnit
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CulturePerGarrisonedUnit *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.CulturePerGarrisonedUnit' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CulturePerGarrisonedUnit <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HappinessPerTradeRoute
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.HappinessPerTradeRoute *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'HappinessPerTradeRoute') AS Flavor,
'Policies.HappinessPerTradeRoute' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.HappinessPerTradeRoute <> 0 AND AnC_Flavor2Yields.YT = 'Happiness' -- = HappinessPerTradeRoute
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HappinessPerXPopulation all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ExtraHappinessPerLuxury
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.ExtraHappinessPerLuxury *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.ExtraHappinessPerLuxury' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.ExtraHappinessPerLuxury <> 0 AND AnC_Flavor2Yields.YT = 'Happiness' -- = ExtraHappinessPerLuxury
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnhappinessFromUnitsMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumExtraBuilders all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.PlotGoldCostMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.PlotGoldCostMod < 0 THEN abs(Policies.PlotGoldCostMod) ELSE Policies.PlotGoldCostMod *-1 END) 
*AnC_Flavor2Yields.Flavor AS Flavor, 'Policies.PlotGoldCostMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.PlotGoldCostMod <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.PlotCultureCostModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.PlotCultureCostModifier < 0 THEN abs(Policies.PlotCultureCostModifier) ELSE Policies.PlotCultureCostModifier *-1 END) 
*AnC_Flavor2Yields.Flavor AS Flavor, 'Policies.PlotCultureCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.PlotCultureCostModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.PlotCultureExponentModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.PlotCultureExponentModifier < 0 THEN abs(Policies.PlotCultureExponentModifier) ELSE Policies.PlotCultureExponentModifier *-1 END) 
*AnC_Flavor2Yields.Flavor AS Flavor, 'Policies.PlotCultureExponentModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.PlotCultureExponentModifier <> 0 AND AnC_Flavor2Yields.YT = 'PlotCultureExponentModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumCitiesPolicyCostDiscount all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GarrisonedCityRangeStrikeModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnitPurchaseCostModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.UnitPurchaseCostModifier < 0 THEN abs(Policies.UnitPurchaseCostModifier) ELSE Policies.UnitPurchaseCostModifier *-1 END) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'UnitPurchaseCostModifier') *AnC_Flavor2Yields.Flavor AS Flavor, 
'Policies.UnitPurchaseCostModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.UnitPurchaseCostModifier <> 0 AND AnC_Flavor2Yields.YT = 'HURRY_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CityConnectionTradeRouteGoldModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CityConnectionTradeRouteGoldModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.CityConnectionTradeRouteGoldModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CityConnectionTradeRouteGoldModifier <> 0 AND AnC_Flavor2Yields.YT = 'CityConnectionTradeRouteGoldModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.TradeMissionGoldModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CulturalPlunderMultiplier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.StealTechSlowerModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldPerUnit all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldPerMilitaryUnit all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.RouteGoldMaintenanceMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.RouteGoldMaintenanceMod < 0 THEN abs(Policies.RouteGoldMaintenanceMod) ELSE Policies.RouteGoldMaintenanceMod *-1 END) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'RouteGoldMaintenanceMod') *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.RouteGoldMaintenanceMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.RouteGoldMaintenanceMod <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.BuildingGoldMaintenanceMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.BuildingGoldMaintenanceMod < 0 THEN abs(Policies.BuildingGoldMaintenanceMod) ELSE Policies.BuildingGoldMaintenanceMod *-1 END) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'BuildingGoldMaintenanceMod') *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.BuildingGoldMaintenanceMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.BuildingGoldMaintenanceMod <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnitGoldMaintenanceMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.UnitGoldMaintenanceMod < 0 THEN abs(Policies.UnitGoldMaintenanceMod) ELSE Policies.UnitGoldMaintenanceMod *-1 END) 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'UnitGoldMaintenanceMod') *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.UnitGoldMaintenanceMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.UnitGoldMaintenanceMod <> 0 AND AnC_Flavor2Yields.YT = 'HURRY_GOLD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnitSupplyMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnitUpgradeCostMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.UnitUpgradeCostMod < 0 THEN abs(Policies.UnitUpgradeCostMod) ELSE Policies.UnitUpgradeCostMod *-1 END) *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.UnitUpgradeCostMod') AS Flavor,
'Policies.UnitUpgradeCostMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.UnitUpgradeCostMod <> 0 AND AnC_Flavor2Yields.YT = 'UnitUpgradeCostMod'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CityStrengthMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CityStrengthMod *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.CityStrengthMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CityStrengthMod <> 0 AND AnC_Flavor2Yields.YT = 'CityStrengthMod'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CityGrowthMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CityGrowthMod *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CityGrowthMod') AS Flavor,
'Policies.CityGrowthMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CityGrowthMod <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_FOOD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CapitalGrowthMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CapitalGrowthMod *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CapitalGrowthMod') AS Flavor,
'Policies.CapitalGrowthMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CapitalGrowthMod <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_FOOD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.SettlerProductionModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CapitalSettlerProductionModifier all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NewCityExtraPopulation
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.NewCityExtraPopulation *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'NewCityExtraPopulation') AS Flavor,
'Policies.NewCityExtraPopulation' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.NewCityExtraPopulation > 0 AND AnC_Flavor2Yields.YT IN ('NewCityExtraPopulation', 'YIELD_POPULATION')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.FreeFoodBox all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HappyPerMilitaryUnit all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MilitaryFoodProduction all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HappinessToCulture
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.HappinessToCulture *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'HappinessToCulture') AS Flavor,
'Policies.HappinessToCulture' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.HappinessToCulture <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HappinessToScience
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.HappinessToScience *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'HappinessToScience') AS Flavor,
'Policies.HappinessToScience' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.HappinessToScience <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumCitiesFreeCultureBuilding all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NumCitiesFreeFoodBuilding all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HalfSpecialistUnhappiness all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.HalfSpecialistFood
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.HalfSpecialistFood *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policies.HalfSpecialistFood') AS Flavor,
'Policies.HalfSpecialistFood' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.HalfSpecialistFood <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_FOOD'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MaxConscript all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.UnitSightRangeChange all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.WoundedUnitDamageMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.BarbarianCombatBonus
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.BarbarianCombatBonus *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.BarbarianCombatBonus' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.BarbarianCombatBonus <> 0 AND AnC_Flavor2Yields.YT = 'BarbarianCombatBonus'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.AlwaysSeeBarbCamps all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.FreeSpecialist all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ExpModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.ExpModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.ExpModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.ExpModifier <> 0 AND AnC_Flavor2Yields.YT = 'ExpModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.ExpInBorderModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.ExpInBorderModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.ExpInBorderModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.ExpInBorderModifier <> 0 AND AnC_Flavor2Yields.YT = 'ExpInBorderModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorQuestFriendshipMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorGoldFriendshipMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorFriendshipMinimum
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.MinorFriendshipMinimum *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.MinorFriendshipMinimum' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have + */ Policies.MinorFriendshipMinimum > 0 AND AnC_Flavor2Yields.YT = 'MinorFriendshipMinimum'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorFriendshipDecayMod
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.MinorFriendshipDecayMod < 0 THEN abs(Policies.MinorFriendshipDecayMod) ELSE Policies.MinorFriendshipDecayMod *-1 END) 
*AnC_Flavor2Yields.Flavor AS Flavor, 'Policies.MinorFriendshipDecayMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.MinorFriendshipDecayMod <> 0 AND AnC_Flavor2Yields.YT = 'MinorFriendshipDecayMod'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.OtherPlayersMinorFriendshipDecayMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, 
(SELECT CASE WHEN Policies.OtherPlayersMinorFriendshipDecayMod < 0 THEN abs(Policies.OtherPlayersMinorFriendshipDecayMod) ELSE Policies.OtherPlayersMinorFriendshipDecayMod *-1 END) 
*AnC_Flavor2Yields.Flavor AS Flavor, 'Policies.OtherPlayersMinorFriendshipDecayMod' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* negative is good - positive is bad */ Policies.OtherPlayersMinorFriendshipDecayMod <> 0 AND AnC_Flavor2Yields.YT = 'MinorFriendshipDecayMod'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.CityStateUnitFrequencyModifier
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.CityStateUnitFrequencyModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.CityStateUnitFrequencyModifier' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.CityStateUnitFrequencyModifier <> 0 AND AnC_Flavor2Yields.YT = 'Policies.CityStateUnitFrequencyModifier'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorGreatPeopleAllies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.MinorGreatPeopleAllies *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.MinorGreatPeopleAllies' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have 0/1 */ Policies.MinorGreatPeopleAllies = 1 AND AnC_Flavor2Yields.YT = 'MinorGreatPeopleAllies'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorScienceAllies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.MinorScienceAllies *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'MinorScienceAllies') AS Flavor, 'Policies.MinorScienceAllies' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can just have 0/1 */ Policies.MinorScienceAllies = 1 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.MinorResourceBonus
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.MinorResourceBonus *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'MinorResourceBonus') AS Flavor, 'Policies.MinorResourceBonus' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.MinorResourceBonus <> 0 AND AnC_Flavor2Yields.YT = 'MinorResourceBonus'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GarrisonFreeMaintenance
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.GarrisonFreeMaintenance *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GarrisonFreeMaintenance') AS Flavor, 'Policies.GarrisonFreeMaintenance' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE /* we can also have negative Yields */ Policies.GarrisonFreeMaintenance <> 0 AND AnC_Flavor2Yields.YT IN ('GarrisonFreeMaintenance', 'YIELD_GOLD')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GoldenAgeCultureBonusDisabled all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.SecondReligionPantheon all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.AddReformationBelief all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.AbleToAnnexCityStates all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.OneShot -- Baustelle (was machen?)
------------------------------------------------------------------------------------------------------------------------------------------------------
/*
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.OneShot *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.OneShot' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE *//* we can just have 0/1 *//* Policies.OneShot = 1 AND AnC_Flavor2Yields.YT = 'OneShot'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.IncludesOneShotFreeUnits -- Baustelle (was machen?)
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policies.Type AS PT, Policies.IncludesOneShotFreeUnits *AnC_Flavor2Yields.Flavor AS Flavor,
'Policies.IncludesOneShotFreeUnits' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policies
WHERE *//* we can just have 0/1 *//* Policies.IncludesOneShotFreeUnits = 1 AND AnC_Flavor2Yields.YT = 'IncludesOneShotFreeUnits'
UNION ALL
*/
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.WeLoveTheKing all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.PuppetUnhappinessModPolicy all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.GarrisonsOccupiedUnhapppinessMod all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NoUnhappinessExpansion all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies.NoUnhappyIsolation all 0
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_BuildingClassCultureChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_BuildingClassCultureChanges.PolicyType AS PT, Policy_BuildingClassCultureChanges.CultureChange 
*(SELECT sum(AnC_AllBU.Weight) /count(AnC_AllBU.BC) FROM AnC_AllBU WHERE AnC_AllBU.BC = Policy_BuildingClassCultureChanges.BuildingClassType) 
*AnC_Flavor2Yields.Flavor AS Flavor,
'Policy_BuildingClassCultureChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_BuildingClassCultureChanges
WHERE /* we can also have negative Yields */ Policy_BuildingClassCultureChanges.CultureChange <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
GROUP BY FT, Policy_BuildingClassCultureChanges.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_BuildingClassHappiness
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_BuildingClassHappiness.PolicyType AS PT, sum(Policy_BuildingClassHappiness.Happiness) 
*(SELECT sum(AnC_AllBU.Weight) /count(AnC_AllBU.BC) FROM AnC_AllBU WHERE AnC_AllBU.BC = Policy_BuildingClassHappiness.BuildingClassType)
*AnC_Flavor2Yields.Flavor AS Flavor, 'Policy_BuildingClassHappiness' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_BuildingClassHappiness
WHERE /* we can also have negative Yields */ Policy_BuildingClassHappiness.Happiness <> 0 AND AnC_Flavor2Yields.YT = 'Policy_BuildingClassHappiness'
GROUP BY FT, Policy_BuildingClassHappiness.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_BuildingClassProductionModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_BuildingClassProductionModifiers.PolicyType AS PT, Policy_BuildingClassProductionModifiers.ProductionModifier 
*(SELECT sum(AnC_AllBU.Weight) /count(AnC_AllBU.BC) FROM AnC_AllBU WHERE AnC_AllBU.BC = Policy_BuildingClassProductionModifiers.BuildingClassType) 
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'BuildingClassXModifiers') *0.02 AS Flavor, 
'Policy_BuildingClassProductionModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_BuildingClassProductionModifiers
WHERE /* we can also have negative Yields */ Policy_BuildingClassProductionModifiers.ProductionModifier <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_PRODUCTION'
GROUP BY FT, Policy_BuildingClassProductionModifiers.PolicyType, Policy_BuildingClassProductionModifiers.BuildingClassType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_BuildingClassYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_BuildingClassYieldChanges.PolicyType AS PT, sum(Policy_BuildingClassYieldChanges.YieldChange) 
*(SELECT sum(AnC_AllBU.Weight) /count(AnC_AllBU.BC) FROM AnC_AllBU WHERE AnC_AllBU.BC = Policy_BuildingClassYieldChanges.BuildingClassType) 
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policy_BuildingClassXChanges') AS Flavor,
'Policy_BuildingClassYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_BuildingClassYieldChanges
WHERE /* we can also have negative Yields */ Policy_BuildingClassYieldChanges.YieldChange <> 0 
AND AnC_Flavor2Yields.YT = Policy_BuildingClassYieldChanges.YieldType
GROUP BY AnC_Flavor2Yields.FT, Policy_BuildingClassYieldChanges.PolicyType, Policy_BuildingClassYieldChanges.YieldType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_BuildingClassYieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_BuildingClassYieldModifiers.PolicyType AS PT, sum(Policy_BuildingClassYieldModifiers.YieldMod) 
*(SELECT sum(AnC_AllBU.Weight) /count(AnC_AllBU.BC) FROM AnC_AllBU WHERE AnC_AllBU.BC = Policy_BuildingClassYieldModifiers.BuildingClassType) 
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'BuildingClassXModifiers') AS Flavor,
'Policy_BuildingClassYieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_BuildingClassYieldModifiers
WHERE /* we can also have negative Yields */ Policy_BuildingClassYieldModifiers.YieldMod <> 0 
AND AnC_Flavor2Yields.YT = Policy_BuildingClassYieldModifiers.YieldType
GROUP BY AnC_Flavor2Yields.FT, Policy_BuildingClassYieldModifiers.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_CapitalYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_CapitalYieldChanges.PolicyType AS PT, sum(Policy_CapitalYieldChanges.Yield) *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policy_CapitalYieldChanges') AS Flavor,
'Policy_CapitalYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_CapitalYieldChanges
WHERE /* we can also have negative Yields */ Policy_CapitalYieldChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Policy_CapitalYieldChanges.YieldType
GROUP BY FT, Policy_CapitalYieldChanges.PolicyType, Policy_CapitalYieldChanges.YieldType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_CapitalYieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_CapitalYieldModifiers.PolicyType AS PT, sum(Policy_CapitalYieldModifiers.Yield *AnC_Flavor2Yields.Flavor) AS Flavor,
'Policy_CapitalYieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_CapitalYieldModifiers
WHERE /* we can also have negative Yields */ Policy_CapitalYieldModifiers.Yield <> 0 
AND AnC_Flavor2Yields.YT = Policy_CapitalYieldModifiers.YieldType
GROUP BY FT, Policy_CapitalYieldModifiers.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_CapitalYieldPerPopChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_CapitalYieldPerPopChanges.PolicyType AS PT, sum(Policy_CapitalYieldPerPopChanges.Yield *AnC_Flavor2Yields.Flavor)
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'CapitalYieldPerPopChanges') AS Flavor,
'Policy_CapitalYieldPerPopChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_CapitalYieldPerPopChanges
WHERE /* we can also have negative Yields */ Policy_CapitalYieldPerPopChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Policy_CapitalYieldPerPopChanges.YieldType
GROUP BY FT, Policy_CapitalYieldPerPopChanges.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_CityYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_CityYieldChanges.PolicyType AS PT, sum(Policy_CityYieldChanges.Yield *AnC_Flavor2Yields.Flavor) AS Flavor,
'Policy_CityYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_CityYieldChanges
WHERE /* we can also have negative Yields */ Policy_CityYieldChanges.Yield <> 0 
AND AnC_Flavor2Yields.YT = Policy_CityYieldChanges.YieldType
GROUP BY FT, Policy_CityYieldChanges.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_CoastalCityYieldChanges --empty
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_FreeItems -- empty
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_FreePromotionUnitCombats -- empty
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_FreePromotions
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_FreePromotions.PolicyType AS PT, count(Policy_FreePromotions.PromotionType) *AnC_Flavor2Yields.Flavor AS Flavor,
'Policy_FreePromotions' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_FreePromotions
WHERE AnC_Flavor2Yields.YT = 'Policy_FreePromotions'
GROUP BY FT, Policy_FreePromotions.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_FreeUnitClasses
------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_HurryModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_HurryModifiers.PolicyType AS PT, 
(SELECT CASE WHEN Policy_HurryModifiers.HurryCostModifier < 0 THEN abs(Policy_HurryModifiers.HurryCostModifier) ELSE Policy_HurryModifiers.HurryCostModifier *-1 END) 
*AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policy_HurryModifiers') AS Flavor, 'Policy_HurryModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_HurryModifiers
WHERE /* negative is good - positive is bad */ Policy_HurryModifiers.HurryCostModifier <> 0 
AND AnC_Flavor2Yields.YT = Policy_HurryModifiers.HurryType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_ImprovementCultureChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_ImprovementCultureChanges.PolicyType AS PT, Policy_ImprovementCultureChanges.CultureChange *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'ImprovementXChanges') AS Flavor, 'Policy_ImprovementCultureChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_ImprovementCultureChanges
WHERE /* we can also have negative Yields */ Policy_ImprovementCultureChanges.CultureChange <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_ImprovementYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_ImprovementYieldChanges.PolicyType AS PT, Policy_ImprovementYieldChanges.Yield *AnC_Flavor2Yields.Flavor 
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'ImprovementXChanges') AS Flavor, 'Policy_ImprovementYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_ImprovementYieldChanges
WHERE /* we can also have negative Yields */ Policy_ImprovementYieldChanges.Yield <> 0 AND AnC_Flavor2Yields.YT = Policy_ImprovementYieldChanges.YieldType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_PrereqORPolicies -- empty
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_SpecialistExtraYields
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_SpecialistExtraYields.PolicyType AS PT, sum(Policy_SpecialistExtraYields.Yield) *AnC_Flavor2Yields.Flavor
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'Policy_SpecialistExtraYields') AS Flavor, 'Policy_SpecialistExtraYields' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_SpecialistExtraYields
WHERE /* we can also have negative Yields */ Policy_SpecialistExtraYields.Yield <> 0 AND Policy_SpecialistExtraYields.YieldType = AnC_Flavor2Yields.YT
GROUP BY AnC_Flavor2Yields.FT, Policy_SpecialistExtraYields.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_UnitCombatFreeExperiences
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Policy_UnitCombatFreeExperiences.PolicyType AS PT, Policy_UnitCombatFreeExperiences.FreeExperience *0.5 AS Flavor,
'Policy_UnitCombatFreeExperiences' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Policy_UnitCombatFreeExperiences
WHERE (AnC_Flavor2UnitAITypes.CC = Policy_UnitCombatFreeExperiences.UnitCombatType OR AnC_Flavor2UnitAITypes.CC = 'UNITCOMBAT_FAKE')
GROUP BY FT, PT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_UnitCombatProductionModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
/*
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Policy_UnitCombatProductionModifiers.PolicyType AS PT, sum(Policy_UnitCombatProductionModifiers.ProductionModifier) 
/count(Policy_UnitCombatProductionModifiers.UnitCombatType) *2 AS Flavor, 'Policy_UnitCombatProductionModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Policy_UnitCombatProductionModifiers
WHERE Policy_UnitCombatProductionModifiers.ProductionModifier <> 0 
AND ((AnC_Flavor2UnitAITypes.CC = Policy_UnitCombatProductionModifiers.UnitCombatType AND AnC_Flavor2UnitAITypes.MP = 1) OR AnC_Flavor2UnitAITypes.CC = 'UNITCOMBAT_FAKE')
GROUP BY AnC_Flavor2UnitAITypes.FT, Policy_UnitCombatProductionModifiers.PolicyType
*/
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Policy_UnitCombatProductionModifiers.PolicyType AS PT, sum(Policy_UnitCombatProductionModifiers.ProductionModifier) 
/count(AnC_Flavor2UnitAITypes.UT) AS Flavor, 'Policy_UnitCombatProductionModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Policy_UnitCombatProductionModifiers
WHERE Policy_UnitCombatProductionModifiers.ProductionModifier <> 0 
AND ((AnC_Flavor2UnitAITypes.CC = Policy_UnitCombatProductionModifiers.UnitCombatType AND AnC_Flavor2UnitAITypes.MP = 1) OR AnC_Flavor2UnitAITypes.CC = 'UNITCOMBAT_FAKE')
GROUP BY AnC_Flavor2UnitAITypes.FT, Policy_UnitCombatProductionModifiers.PolicyType, AnC_Flavor2UnitAITypes.CC
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_ValidSpecialists -- empty
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_YieldModifiers
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Policy_YieldModifiers.PolicyType AS PT, sum(Policy_YieldModifiers.Yield *AnC_Flavor2Yields.Flavor) *0.1
*(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'GlobalXModifiers') AS Flavor,
'Policy_YieldModifiers' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Policy_YieldModifiers
WHERE /* we can also have negative Yields */ Policy_YieldModifiers.Yield <> 0 
AND AnC_Flavor2Yields.YT = Policy_YieldModifiers.YieldType
GROUP BY FT, PT
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Policies END
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_Disables
-- PolicyBranch_Disables



------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Tech
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2Tech' ('TT' TEXT, 'FT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);

DELETE FROM AnC_Flavor2Tech;

INSERT INTO 'AnC_Flavor2Tech' (TT, FT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Buildings.PrereqTech AS TT, Building_Flavors.FlavorType AS FT, Building_Flavors.Flavor 
*(SELECT AnC_AllBU.Weight FROM AnC_AllBU WHERE AnC_AllBU.BT = Buildings.Type) *0.25 AS Flavor, 
(SELECT ("Buildings."||Buildings.Type)) AS FromTable, 'Vanilla' AS Mod
FROM Buildings, Building_Flavors, BuildingClasses
WHERE Buildings.Type = BuildingClasses.DefaultBuilding
AND Buildings.PrereqTech NOT NULL 
AND BuildingClasses.DefaultBuilding = Building_Flavors.BuildingType
GROUP BY Buildings.PrereqTech, Building_Flavors.FlavorType, Building_Flavors.BuildingType
UNION ALL
--
SELECT Building_TechAndPrereqs.TechType AS TT, Building_Flavors.FlavorType AS FT, Building_Flavors.Flavor
*(SELECT AnC_AllBU.Weight FROM AnC_AllBU WHERE AnC_AllBU.BT = Building_TechAndPrereqs.BuildingType) *0.25 AS Flavor, 
(SELECT ("Building_TechAndPrereqs."||Building_TechAndPrereqs.BuildingType)) AS FromTable, 'Vanilla' AS Mod
FROM Building_TechAndPrereqs, Building_Flavors, BuildingClasses
WHERE Building_TechAndPrereqs.BuildingType = BuildingClasses.DefaultBuilding
AND BuildingClasses.DefaultBuilding = Building_Flavors.BuildingType
GROUP BY Building_TechAndPrereqs.TechType, Building_Flavors.FlavorType, Building_Flavors.BuildingType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Builds / Improvements
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Builds2Improvements.PT AS TT, Build_Flavors.FlavorType AS FT, Build_Flavors.Flavor *0.25 AS Flavor, 'Builds/Improvements' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Builds2Improvements, Build_Flavors
WHERE AnC_Builds2Improvements.PT NOT NULL AND AnC_Builds2Improvements.BT = Build_Flavors.BuildType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_TechFreshWaterYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Improvement_TechFreshWaterYieldChanges.TechType AS TT, AnC_Flavor2Yields.FT AS FT, Improvement_TechFreshWaterYieldChanges.Yield 
*AnC_Flavor2Yields.Flavor *0.25 AS Flavor, 'Improvement_TechFreshWaterYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM Improvement_TechFreshWaterYieldChanges, AnC_Flavor2Yields
WHERE Improvement_TechFreshWaterYieldChanges.YieldType = AnC_Flavor2Yields.YT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_TechNoFreshWaterYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Improvement_TechNoFreshWaterYieldChanges.TechType AS TT, AnC_Flavor2Yields.FT AS FT, Improvement_TechNoFreshWaterYieldChanges.Yield 
*AnC_Flavor2Yields.Flavor *0.25 AS Flavor, 'Improvement_TechNoFreshWaterYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM Improvement_TechNoFreshWaterYieldChanges, AnC_Flavor2Yields
WHERE Improvement_TechNoFreshWaterYieldChanges.YieldType = AnC_Flavor2Yields.YT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_TechYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Improvement_TechYieldChanges.TechType AS TT, AnC_Flavor2Yields.FT AS FT, Improvement_TechYieldChanges.Yield 
*AnC_Flavor2Yields.Flavor *0.25 AS Flavor, 'Improvement_TechYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM Improvement_TechYieldChanges, AnC_Flavor2Yields
WHERE Improvement_TechYieldChanges.YieldType = AnC_Flavor2Yields.YT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Policies.TechPrereq AS TT, Policy_Flavors.FlavorType AS FT, Policy_Flavors.Flavor *0.25 AS Flavor, 'Policies.TechPrereq' AS FromTable, 'Vanilla' AS Mod
FROM Policies, Policy_Flavors
WHERE Policies.TechPrereq NOT NULL AND Policies.Type = Policy_Flavors.PolicyType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Processes / Resolutions BNW / Process_Flavors GnK
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Processes.TechPrereq AS TT, Process_Flavors.FlavorType AS FT, Process_Flavors.Flavor *0.25 AS Flavor, 'Processes.TechPrereq' AS FromTable, 'Vanilla' AS Mod
FROM Processes, Process_Flavors
WHERE Processes.TechPrereq NOT NULL AND Processes.Type = Process_Flavors.ProcessType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Projects
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Projects.TechPrereq AS TT, Project_Flavors.FlavorType AS FT, Project_Flavors.Flavor *0.25 AS Flavor, 'Projects.TechPrereq' AS FromTable, 'Vanilla' AS Mod
FROM Projects, Project_Flavors
WHERE Projects.TechPrereq NOT NULL AND Projects.Type = Project_Flavors.ProjectType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Resources
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Resources.TechReveal AS TT, Resource_Flavors.FlavorType AS FT, Resource_Flavors.Flavor *0.25 AS Flavor, 'Resources.TechReveal' AS FromTable, 'Vanilla' AS Mod
FROM Resources, Resource_Flavors
WHERE Resources.TechReveal NOT NULL AND Resources.Type = Resource_Flavors.ResourceType
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Route_TechMovementChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Route_TechMovementChanges.TechType AS TT, AnC_Flavor2Yields.FT AS FT, 
(SELECT CASE WHEN Route_TechMovementChanges.MovementChange < 0 THEN abs(Route_TechMovementChanges.MovementChange) 
ELSE Route_TechMovementChanges.MovementChange *-1 END) *AnC_Flavor2Yields.Flavor AS Flavor, 'Route_TechMovementChanges' AS FromTable, 'Vanilla' AS Mod
FROM Route_TechMovementChanges, AnC_Flavor2Yields
WHERE /* negative is good - positive is bad */ Route_TechMovementChanges.MovementChange <> 0 AND AnC_Flavor2Yields.YT = 'TechMovementChanges'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Technologies
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.WorkerSpeedModifier *AnC_Flavor2Yields.Flavor *0.25 AS Flavor, 
'Technologies.WorkerSpeedModifier' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.WorkerSpeedModifier <> 0 AND AnC_Flavor2Yields.YT = 'WorkerSpeedModifier'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.FirstFreeTechs *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.FirstFreeTechs' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.FirstFreeTechs > 0 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.EmbarkedMoveChange *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.EmbarkedMoveChange' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.EmbarkedMoveChange <> 0 AND AnC_Flavor2Yields.YT = 'EmbarkedMoveChange'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.AllowsEmbarking *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.AllowsEmbarking' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.AllowsEmbarking = 1 AND AnC_Flavor2Yields.YT = 'EmbarkedMoveChange'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.AllowsDefensiveEmbarking *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.AllowsDefensiveEmbarking' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.AllowsDefensiveEmbarking = 1 AND AnC_Flavor2Yields.YT = 'EmbarkedMoveChange'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.MapVisible *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.MapVisible' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.MapVisible = 1 AND AnC_Flavor2Yields.YT = 'MapVisible'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.MapTrading *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.MapTrading' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.MapTrading = 1 AND AnC_Flavor2Yields.YT IN ('MapTrading', 'YIELD_GOLD')
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.TechTrading *AnC_Flavor2Yields.Flavor *2 AS Flavor, 
'Technologies.TechTrading' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.TechTrading = 1 AND AnC_Flavor2Yields.YT IN ('YIELD_GOLD', 'YIELD_SCIENCE')
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.GoldTrading *AnC_Flavor2Yields.Flavor *2 AS Flavor, 
'Technologies.GoldTrading' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.GoldTrading = 1 AND AnC_Flavor2Yields.YT IN ('YIELD_GOLD')
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.OpenBordersTradingAllowed *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.OpenBordersTradingAllowed' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.OpenBordersTradingAllowed = 1 AND AnC_Flavor2Yields.YT = 'OpenBordersTradingAllowed'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.DefensivePactTradingAllowed *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.DefensivePactTradingAllowed' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.DefensivePactTradingAllowed = 1 AND AnC_Flavor2Yields.YT = 'DefensivePactTradingAllowed'
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.ResearchAgreementTradingAllowed *AnC_Flavor2Yields.Flavor *2 AS Flavor, 
'Technologies.ResearchAgreementTradingAllowed' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.ResearchAgreementTradingAllowed = 1 AND AnC_Flavor2Yields.YT IN ('ResearchAgreementTradingAllowed', 'YIELD_SCIENCE')
UNION ALL
--
/* 
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.TradeAgreementTradingAllowed *AnC_Flavor2Yields.Flavor *2 AS Flavor, 
'Technologies.TradeAgreementTradingAllowed' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.TradeAgreementTradingAllowed = 1 AND AnC_Flavor2Yields.YT IN ('TradeAgreementTradingAllowed', 'YIELD_GOLD')
UNION ALL
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.PermanentAllianceTradingAllowed *AnC_Flavor2Yields.Flavor *2 AS Flavor, 
'Technologies.PermanentAllianceTradingAllowed' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.PermanentAllianceTradingAllowed = 1 AND AnC_Flavor2Yields.YT IN ('PermanentAllianceTradingAllowed')
UNION ALL
*/
--
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.BridgeBuilding *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.BridgeBuilding' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.BridgeBuilding = 1 AND AnC_Flavor2Yields.YT = 'BridgeBuilding'
UNION ALL
-- 
SELECT Technologies.Type AS TT, AnC_Flavor2Yields.FT AS FT, Technologies.Repeat *AnC_Flavor2Yields.Flavor AS Flavor, 
'Technologies.Repeat' AS FromTable, 'Vanilla' AS Mod
FROM Technologies, AnC_Flavor2Yields
WHERE Technologies.Repeat = 1 AND AnC_Flavor2Yields.YT = 'Repeat'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Technology_DomainExtraMoves
------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Technology_FreePromotions
------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Terrain_TechYieldChanges
------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------
-- UnitPromotions
------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Units
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Units.PrereqTech AS TT, Unit_Flavors.FlavorType AS FT, Unit_Flavors.Flavor *0.25 AS Flavor, 'Units.PrereqTech' AS FromTable, 'Vanilla' AS Mod
FROM Units, Unit_Flavors, UnitClasses
WHERE Units.Type = UnitClasses.DefaultUnit
AND Units.PrereqTech NOT NULL AND Units.Type = Unit_Flavors.UnitType
UNION ALL
--
SELECT Unit_TechTypes.TechType AS TT, Unit_Flavors.FlavorType AS FT, Unit_Flavors.Flavor *0.25 AS Flavor, 'Unit_TechTypes.TechType' AS FromTable, 'Vanilla' AS Mod
FROM Unit_TechTypes, Unit_Flavors, UnitClasses
WHERE Unit_TechTypes.UnitType = UnitClasses.DefaultUnit
AND Unit_TechTypes.UnitType = Unit_Flavors.UnitType
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Tech END
------------------------------------------------------------------------------------------------------------------------------------------------------


-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Executed = 1 WHERE File = 'AnC_NewFlavors1_STOCK.sql';