-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Loaded = 1 WHERE File = 'AnC_NewFlavors99.sql';
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Resource_Flavors
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM Resource_Flavors;

INSERT INTO Resource_Flavors (ResourceType, FlavorType, Flavor)
SELECT RT, FT, round(sum(Flavor) /count(AnC_Flavor2Resources.RT)) AS Flavor
FROM AnC_Flavor2Resources WHERE Flavor > 0
GROUP BY RT, FT;

DELETE FROM Resource_Flavors WHERE Flavor < 2.5;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Process_Flavors (after Building_Flavors!)
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM Process_Flavors;

INSERT INTO Process_Flavors (ProcessType, FlavorType, Flavor)
SELECT PT, FT, sum(Flavor) AS Flavor
FROM AnC_Flavor2Processes WHERE Flavor > 0
GROUP BY PT, FT;

DELETE FROM Process_Flavors WHERE Flavor < 2.5;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Policy_Flavors
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM Policy_Flavors;

INSERT INTO Policy_Flavors (PolicyType, FlavorType, Flavor)
SELECT PT, FT, round(sum(Flavor),2) AS Flavor
FROM AnC_Flavor2Policies
GROUP BY PT, FT;

--DELETE FROM Policy_Flavors WHERE Flavor < 2.5;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Technology_Flavors
------------------------------------------------------------------------------------------------------------------------------------------------------
DELETE FROM Technology_Flavors;

INSERT INTO Technology_Flavors (TechType, FlavorType, Flavor)
SELECT AnC_Flavor2Tech.TT, AnC_Flavor2Tech.FT, round(sum(AnC_Flavor2Tech.Flavor *AnC_Era2Tech.TechFlavMul),1) AS Flavor
FROM AnC_Flavor2Tech, AnC_Era2Tech
WHERE AnC_Flavor2Tech.TT = AnC_Era2Tech.Type
GROUP BY AnC_Flavor2Tech.TT, AnC_Flavor2Tech.FT;

DELETE FROM Technology_Flavors WHERE Flavor < 1.5;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Reporting
------------------------------------------------------------------------------------------------------------------------------------------------------
DROP VIEW IF EXISTS AnC_DebugCheck_NE;

-- which files are not loaded?
CREATE VIEW IF NOT EXISTS AnC_DebugCheck_NE AS
SELECT File, 'ERROR' AS Status, Mod, 'File NOT loaded! Please report Bug - Thx.' AS Info
FROM AnC_DebugCheck
WHERE Loaded = 0 AND Mod != 'afterAnC'
UNION ALL
--
SELECT File, 'ERROR' AS Status, Mod, 'File NOT executed! All Flavor''s will not work! Please report Bug - Thx.' AS Info
FROM AnC_DebugCheck
WHERE Executed = 0 AND File IN 
('AnC_QueryViews1A_STOCK.sql', 'AnC_QueryViews1B_YIELDS.sql', 'AnC_QueryViews1C_STOCK.sql', 'AnC_QueryViews99.sql', 'AnC_NewFlavors1_STOCK.sql', 'AnC_NewFlavors91_STOCK.sql', 'AnC_NewFlavors99.sql')
UNION ALL
--
SELECT File, 'INFO' AS Status, Mod, 'This MOD is not active. File NOT loaded!' AS Info
FROM AnC_DebugCheck
WHERE Executed = 0 AND File NOT IN 
('AnC_QueryViews1A_STOCK.sql', 'AnC_QueryViews1B_YIELDS.sql', 'AnC_QueryViews1C_STOCK.sql', 'AnC_QueryViews99.sql', 'AnC_NewFlavors1_STOCK.sql', 'AnC_NewFlavors99.sql')
UNION ALL
--
SELECT File, 'OK' AS Status, Mod, 'MOD is active' AS Info
FROM AnC_DebugCheck
WHERE Executed = 1 AND Mod != 'afterAnC'
UNION ALL
--
-- any Flavor's added after AnC?
SELECT File, 'WARNING' AS Status, Mod, 'Flavor''s are added AFTER AnC_NewFlavors! Your Mod will maybe not work as expected' AS Info
FROM AnC_DebugCheck
WHERE File = 'Building_Flavors_INSERT' AND Mod = 'afterAnC'
UNION ALL
--
-- any update attempts?
SELECT File, 'WARNING' AS Status, Mod, 'There are a dropped update AFTER AnC_NewFlavors! Your Mod will maybe not work as expected' AS Info
FROM AnC_DebugCheck
WHERE File = 'Building_Flavors_UPDATE' AND Mod = 'afterAnC'
UNION ALL
--
-- any delete attempts?
SELECT File, 'WARNING' AS Status, Mod, 'There are a dropped delete AFTER AnC_NewFlavors! Your Mod will maybe not work as expected' AS Info
FROM AnC_DebugCheck
WHERE File = 'Building_Flavors_DELETE' AND Mod = 'afterAnC'
UNION ALL
--
-- did we missed something?
SELECT Buildings.Type AS File, 'WARNING' AS Status, 'AnC' AS Mod, 'This Building has no Flavor!' AS Info 
FROM Buildings
WHERE Buildings.Type NOT IN (SELECT BuildingType FROM Building_Flavors)
UNION ALL
--
SELECT Builds.Type AS File, 'INFO' AS Status, 'AnC' AS Mod, 'This Build has no Flavor!' AS Info 
FROM Builds
WHERE Builds.Type NOT IN (SELECT BuildType FROM Build_Flavors)
UNION ALL
--
SELECT Improvements.Type AS File, 'INFO' AS Status, 'AnC' AS Mod, 'This Improvement has no Flavor!' AS Info 
FROM Improvements
WHERE Improvements.Type NOT IN (SELECT ImprovementType FROM Improvement_Flavors)
UNION ALL
--
SELECT Leaders.Type AS File, 'WARNING' AS Status, 'Vanilla' AS Mod, 'This Leader has no Flavor!' AS Info 
FROM Leaders
WHERE Leaders.Type NOT IN (SELECT LeaderType FROM Leader_Flavors)
UNION ALL
--
SELECT Policies.Type AS File, 'WARNING' AS Status, 'AnC' AS Mod, 'This Policy has no Flavor!' AS Info 
FROM Policies
WHERE Policies.Type NOT IN (SELECT PolicyType FROM Policy_Flavors)
UNION ALL
--
SELECT Processes.Type AS File, 'INFO' AS Status, 'AnC' AS Mod, 'This Process has no Flavor!' AS Info 
FROM Processes
WHERE Processes.Type NOT IN (SELECT ProcessType FROM Process_Flavors)
UNION ALL
--
SELECT Projects.Type AS File, 'WARNING' AS Status, 'AnC' AS Mod, 'This Project has no Flavor!' AS Info 
FROM Projects
WHERE Projects.Type NOT IN (SELECT ProjectType FROM Project_Flavors)
AND Projects.Type NOT IN ('PROJECT_SS_BOOSTER', 'PROJECT_SS_COCKPIT', 'PROJECT_SS_ENGINE', 'PROJECT_SS_STASIS_CHAMBER')
UNION ALL
--
SELECT Resources.Type AS File, 'INFO' AS Status, 'AnC' AS Mod, 'This Resource has no Flavor!' AS Info 
FROM Resources
WHERE Resources.Type NOT IN (SELECT ResourceType FROM Resource_Flavors)
UNION ALL
--
SELECT Technologies.Type AS File, 'WARNING' AS Status, 'AnC' AS Mod, 'This Technology has no Flavor!' AS Info 
FROM Technologies
WHERE Technologies.Type NOT IN (SELECT TechType FROM Technology_Flavors)
UNION ALL
--
SELECT Units.Type AS File, 'INFO' AS Status, 'Vanilla' AS Mod, 'This Unit has no Flavor!' AS Info 
FROM Units
WHERE Units.Type NOT IN (SELECT UnitType FROM Unit_Flavors)
UNION ALL
--
SELECT Yields.Type AS File, 'INFO' AS Status, 'AnC' AS Mod, 'This Yield has no Flavor!' AS Info 
FROM Yields
WHERE Yields.Type NOT IN (SELECT YieldType FROM Yield_Flavors);


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Housekeeping!
------------------------------------------------------------------------------------------------------------------------------------------------------
DROP VIEW IF EXISTS 'AnC_JustUU';
DROP VIEW IF EXISTS 'AnC_JustUn_BarbMinor';
DROP VIEW IF EXISTS 'AnC_JustUn_NOTbuildable';
DROP VIEW IF EXISTS 'AnC_JustUnUU';
DROP VIEW IF EXISTS 'AnC_JustUNnUU';
DROP VIEW IF EXISTS 'AnC_AllUN';
DROP VIEW IF EXISTS 'AnC_JustUB';
DROP VIEW IF EXISTS 'AnC_JustBuUB';
DROP VIEW IF EXISTS 'AnC_JustBUnUB';
DROP VIEW IF EXISTS 'AnC_JustBUnUB';
DROP VIEW IF EXISTS 'AnC_AllBU';
DROP VIEW IF EXISTS 'AnC_JustWW';
DROP VIEW IF EXISTS 'AnC_JustNW';
DROP VIEW IF EXISTS 'AnC_JustUUaUB';
DROP VIEW IF EXISTS 'AnC_GreatPersons2Builds';
DROP VIEW IF EXISTS 'AnC_GreatPersons2Yields';
DROP VIEW IF EXISTS 'AnC_Builds2Improvements';
DROP VIEW IF EXISTS 'AnC_Focus2SpecialistType';
DROP VIEW IF EXISTS 'AnC_Focus2BuildingType';
DROP VIEW IF EXISTS 'AnC_Flavor2UnitAITypes';
DROP VIEW IF EXISTS 'AnC_Yields';
DROP VIEW IF EXISTS 'AnC_Flavor2Resources';
DROP VIEW IF EXISTS 'AnC_Flavor2Improvement_Yields';
DROP VIEW IF EXISTS 'AnC_Flavor2Improvements';
DROP VIEW IF EXISTS 'AnC_Flavor2GreatPersons';
DROP VIEW IF EXISTS 'AnC_NeededByEra';
DROP VIEW IF EXISTS 'AnC_Compare_Building_Flavors';
DROP VIEW IF EXISTS 'AnC_Era2Tech';
DROP VIEW IF EXISTS 'AnC_Flavor2Building_FreeUnits';
DROP VIEW IF EXISTS 'AnC_BuildingsYield_View';
DROP VIEW IF EXISTS 'AnC_Flavor2GoodyHuts';
DROP TABLE IF EXISTS 'AnC_Flavor2Yields';
DROP TABLE IF EXISTS 'AnC_Flavor2GoodyHutsT';
DROP TABLE IF EXISTS 'AnC_Flavor2Improvement_YieldsT';
DROP TABLE IF EXISTS 'AnC_Flavor2ResourcesT';
DROP TABLE IF EXISTS 'AnC_GreatPersons2YieldsT';
DROP TABLE IF EXISTS 'AnC_Flavor2Tech';
DROP TABLE IF EXISTS 'AnC_Flavor2Policies';
DROP TABLE IF EXISTS 'AnC_Flavor2Processes';


-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Executed = 1 WHERE File = 'AnC_NewFlavors99.sql';