-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Loaded = 1 WHERE File = 'AnC_QueryViews1A_STOCK.sql';
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_QueryViews1A_STOCK
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Create some Tables for Civ versions without
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'Yield_Flavors' ('YieldType' text, 'FlavorType' text, 'Flavor' integer  not null, 
foreign key (YieldType) references Yields(Type), foreign key (FlavorType) references Flavors(Type));

CREATE TABLE IF NOT EXISTS 'Build_Flavors' ('BuildType' text REFERENCES Builds(Type), 'FlavorType' text REFERENCES Flavors(Type), 'Flavor' integer);

CREATE TABLE IF NOT EXISTS 'Process_Flavors' ('ProcessType' text, 'FlavorType' text, 'Flavor' integer  not null, 
foreign key (ProcessType) references Processes(Type), foreign key (FlavorType) references Flavors(Type));

CREATE TABLE IF NOT EXISTS 'GreatWorkClasses' ('ID' integer primary key autoincrement, 'Type' text  not null unique, 'SlotType' text, 
foreign key (SlotType) references GreatWorkSlots(Type));


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Create some Views for shorter Queries
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Unique Units (without Barbarian & Minor)
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUU' AS
SELECT UnitType AS UT, UnitClassType AS UC, Units.CombatClass AS CC, Units.MilitaryProduction AS MP, Units.Cost, CivilizationType AS CT
FROM Civilization_UnitClassOverrides, Units
WHERE CivilizationType NOT IN ('CIVILIZATION_BARBARIAN', 'CIVILIZATION_MINOR')
AND Civilization_UnitClassOverrides.UnitType = Units.Type
ORDER BY UC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Barbarian & Minor Units
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUn_BarbMinor' AS
SELECT UnitType AS UT, UnitClassType AS UC, Units.CombatClass AS CC, CivilizationType AS CT
FROM Civilization_UnitClassOverrides, Units
WHERE CivilizationType IN ('CIVILIZATION_BARBARIAN', 'CIVILIZATION_MINOR')
AND Civilization_UnitClassOverrides.UnitType = Units.Type
ORDER BY UC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Units which we can not build
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUn_NOTbuildable' AS
SELECT Type AS UT, Units.Class AS UC, Units.CombatClass AS CC, 'MinorCivGift 1/Cost -1' AS CT
FROM Units
WHERE MinorCivGift = 1 OR Cost = -1 AND Class NOT IN (SELECT GreatPeopleUnitClass FROM Specialists) 
ORDER BY UC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Units without UU/Barbarian & Minor
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUnUU' AS
SELECT Type AS UT, Units.Class AS UC, Units.CombatClass AS CC, 'CIVILIZATION_REST' AS CT
FROM Units
WHERE UT NOT IN (SELECT UT FROM AnC_JustUU UNION SELECT UT FROM AnC_JustUn_BarbMinor)
ORDER BY UC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Units +UU
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUNnUU' AS
SELECT UT, UC, CC, CT
FROM AnC_JustUU
UNION ALL
SELECT UT, UC, CC, CT
FROM AnC_JustUnUU
ORDER BY UC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- All Units (incl. UU) without Barbarian/Minor & not buildable
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_AllUN' AS
SELECT UT, UC, CC, MP, Cost, CT
FROM AnC_JustUU
UNION ALL
SELECT Units.Type AS UT, Class AS UC, Units.CombatClass AS CC, Units.MilitaryProduction AS MP, Cost, 'CIVILIZATION_REST' AS CT
FROM Units
WHERE UT NOT IN (SELECT UT FROM AnC_JustUU UNION ALL SELECT UT FROM AnC_JustUn_BarbMinor UNION SELECT UT FROM AnC_JustUn_NOTbuildable)
ORDER BY UC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Unique Buildings
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUB' AS
SELECT BuildingType AS BT, BuildingClassType AS BC, CivilizationType AS CT, 
(SELECT CASE 
WHEN BuildingClassType IN (SELECT Type FROM BuildingClasses WHERE MaxGlobalInstances >= 1 OR MaxTeamInstances >= 1) THEN 0.125 
WHEN BuildingClassType IN (SELECT Type FROM BuildingClasses WHERE MaxPlayerInstances = 1 AND Type NOT IN ('BUILDINGCLASS_SALTERN', 'BUILDINGCLASS_DEEP_DRILLING_PLATFORM', 'BUILDINGCLASS_NUCLEAR_FISSION_REACTOR_PLANT')) THEN 0.5
ELSE 1 END) AS Weight
FROM Civilization_BuildingClassOverrides 
WHERE CivilizationType NOT IN ('CIVILIZATION_BARBARIAN', 'CIVILIZATION_MINOR')
ORDER BY BC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings -UB
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustBuUB' AS
SELECT Type AS BT, BuildingClass AS BC, 'CIVILIZATION_REST' AS CT
FROM Buildings
WHERE BT NOT IN (SELECT BT FROM AnC_JustUB)
ORDER BY BC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- Buildings +UB
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustBUnUB' AS
SELECT BT, BC, CT
FROM AnC_JustUB
UNION ALL
SELECT BT, BC, CT
FROM AnC_JustBuUB
ORDER BY BC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- WorldWonders
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustWW' AS
SELECT DefaultBuilding AS WWT, Type AS WWBC, 'CIVILIZATION_REST' AS CT, 0.125 AS Weight
FROM BuildingClasses
WHERE MaxGlobalInstances >= 1 OR MaxTeamInstances >= 1
ORDER BY WWBC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- NationalWonders
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustNW' AS
SELECT DefaultBuilding AS NWT, Type AS NWBC, 'CIVILIZATION_REST' AS CT, 0.5 AS Weight
FROM BuildingClasses
WHERE MaxPlayerInstances = 1 AND Type NOT IN ('BUILDINGCLASS_SALTERN', 'BUILDINGCLASS_DEEP_DRILLING_PLATFORM', 'BUILDINGCLASS_NUCLEAR_FISSION_REACTOR_PLANT')
ORDER BY NWBC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- All Buildings (incl. UB/NW/WW)
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_AllBU' AS
SELECT BT, BC, CT, Weight
FROM AnC_JustUB
UNION ALL
--
SELECT WWT AS BT, WWBC AS BC, CT, Weight
FROM AnC_JustWW
UNION ALL
--
SELECT NWT AS BT, NWBC AS BC, CT, Weight
FROM AnC_JustNW
UNION ALL
--
SELECT Type AS BT, BuildingClass AS BC, 'CIVILIZATION_REST' AS CT, (SELECT CASE WHEN BuildingClass IN ('BUILDINGCLASS_COURTHOUSE') THEN 0.25 ELSE 1 END) AS Weight
FROM Buildings
WHERE BT NOT IN (SELECT BT FROM AnC_JustUB) AND BT NOT IN (SELECT NWT FROM AnC_JustNW) AND BT NOT IN (SELECT WWT FROM AnC_JustWW)
ORDER BY BC;

------------------------------------------------------------------------------------------------------------------------------------------------------
-- UU with there own UB
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_JustUUaUB' AS
SELECT AnC_JustUU.UT AS UT, AnC_JustUU.UC AS UC, AnC_JustUU.CC AS CC, AnC_JustUU.CT AS UCT, AnC_JustUB.BT AS BT, AnC_JustUB.BC AS BC, AnC_JustUB.CT AS BCT, 'Building_UnitCombatProductionModifiersUU2UB' AS FromTable
FROM AnC_JustUU, Building_UnitCombatProductionModifiers, AnC_JustUB
WHERE (Building_UnitCombatProductionModifiers.BuildingType = AnC_JustUB.BT AND Building_UnitCombatProductionModifiers.UnitCombatType = AnC_JustUU.CC)
AND AnC_JustUU.CT = AnC_JustUB.CT;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Era2Tech
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_Era2Tech' AS
-- 1 ERA_ANCIENT 
SELECT 1 AS EraNr, 9 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 40 AS EraMul, 1.25 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_ANCIENT'
UNION ALL
-- 2 ERA_CLASSICAL 
SELECT 2 AS EraNr, 8 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 10 AS EraMul, 1.5 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_CLASSICAL'
UNION ALL
-- 3 ERA_MEDIEVAL 
SELECT 3 AS EraNr, 7 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 5 AS EraMul, 1.75 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_MEDIEVAL'
UNION ALL
-- 4 ERA_RENAISSANCE 
SELECT 4 AS EraNr, 6 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 1 AS EraMul, 2 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_RENAISSANCE'
UNION ALL
-- 5 ERA_INDUSTRIAL 
SELECT 5 AS EraNr, 5 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 1 AS EraMul, 2.25 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_INDUSTRIAL'
UNION ALL
-- 6 ERA_MODERN 
SELECT 6 AS EraNr, 4 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 1 AS EraMul, 2.5 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_MODERN'
UNION ALL
-- 7 ERA_POSTMODERN 
SELECT 7 AS EraNr, 3 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 2 AS EraMul, 2.75 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_POSTMODERN'
UNION ALL
-- 8 ERA_FUTURE 
SELECT 8 AS EraNr, 2 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 0.1 AS EraMul, 3 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_FUTURE'
UNION ALL
-- 9 ERA_REAL_FUTURE
SELECT 9 AS EraNr, 1 AS EraNr2, Technologies.Era AS Era, Technologies.Type, 1 AS EraMul, 3.25 AS TechFlavMul
FROM Technologies WHERE Technologies.Era = 'ERA_REAL_FUTURE'
------------------------------------------------------------------------------------------------------------------------------------------------------
ORDER BY EraNr;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Era2Tech END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2UnitAITypes
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_Flavor2UnitAITypes' AS
SELECT Flavors.Type AS FT, Unit_AITypes.UnitType AS UT, AnC_AllUN.UC, Units.Domain, Units.CombatClass AS CC, Units.MilitaryProduction AS MP, Unit_AITypes.UnitAIType AS AIT, AnC_AllUN.CT AS CT
FROM Flavors, Unit_AITypes, AnC_AllUN, Units
WHERE (
Flavors.Type = 'FLAVOR_AIR' AND (Unit_AITypes.UnitAIType IN ('UNITAI_ATTACK_AIR', 'UNITAI_CARRIER_AIR', 'UNITAI_CARRIER_SEA', 'UNITAI_CITY_SPECIAL', 'UNITAI_DEFENSE_AIR', 
															'UNITAI_ICBM', 'UNITAI_MISSILE_AIR', 'UNITAI_PARADROP') 
							OR Units.CombatClass IN ('UNITCOMBAT_HELICOPTER') AND Unit_AITypes.UnitAIType IN ('UNITAI_FAST_ATTACK'))
--
--OR Flavors.Type = 'FLAVOR_AIRLIFT' AND Unit_AITypes.UnitAIType IN ()
--
OR Flavors.Type = 'FLAVOR_AIR_CARRIER' AND Unit_AITypes.UnitAIType IN ('UNITAI_CARRIER_AIR', 'UNITAI_CARRIER_SEA')
--
OR Flavors.Type = 'FLAVOR_ANTIAIR' AND Unit_AITypes.UnitAIType IN ('UNITAI_DEFENSE_AIR', 'UNITAI_CITY_SPECIAL')
--
OR Flavors.Type = 'FLAVOR_ARCHAEOLOGY' AND Unit_AITypes.UnitAIType IN ('UNITAI_ARCHAEOLOGIST')
--
OR Flavors.Type = 'FLAVOR_CITY_DEFENSE' AND Unit_AITypes.UnitAIType IN ('UNITAI_CITY_SPECIAL', 'UNITAI_DEFENSE_AIR')
--
OR Flavors.Type = 'FLAVOR_CULTURE' AND Unit_AITypes.UnitAIType IN ('UNITAI_ARTIST', 'UNITAI_MUSICIAN', 'UNITAI_WRITER')
--
OR Flavors.Type = 'FLAVOR_DEFENSE' AND Unit_AITypes.UnitAIType IN ('UNITAI_CITY_SPECIAL', 'UNITAI_DEFENSE', 'UNITAI_COUNTER', 'UNITAI_RANGED', 'UNITAI_ESCORT_SEA', 
									'UNITAI_DEFENSE_AIR', 'UNITAI_MISSILE_AIR', 'UNITAI_RANGED', 'UNITAI_ADMIRAL', 'UNITAI_GENERAL')
--
OR Flavors.Type = 'FLAVOR_DIPLOMACY' AND Unit_AITypes.UnitAIType IN ('UNITAI_DIPLOMAT', 'UNITAI_MESSENGER')
--
--OR Flavors.Type = 'FLAVOR_ESPIONAGE' AND Unit_AITypes.UnitAIType IN ()
--
OR Flavors.Type = 'FLAVOR_EXPANSION' AND Unit_AITypes.UnitAIType IN ('UNITAI_SETTLE')
--
OR Flavors.Type = 'FLAVOR_GOLD' AND Unit_AITypes.UnitAIType IN ('UNITAI_MERCHANT', 'UNITAI_TRADE_UNIT')
--
OR Flavors.Type = 'FLAVOR_GREAT_PEOPLE' AND (Unit_AITypes.UnitAIType IN ('UNITAI_ENGINEER', 'UNITAI_MERCHANT', 'UNITAI_ARTIST', 'UNITAI_MUSICIAN', 'UNITAI_WRITER')
										AND Units.Type NOT IN ('UNIT_TBM'))
--
OR Flavors.Type = 'FLAVOR_GROWTH' AND Unit_AITypes.UnitAIType IN ('UNITAI_MERCHANT')
--
--OR Flavors.Type = 'FLAVOR_HAPPINESS' AND Unit_AITypes.UnitAIType IN ()
--
OR Flavors.Type = 'FLAVOR_INFRASTRUCTURE' AND Unit_AITypes.UnitAIType IN ('UNITAI_WORKER')
--
OR Flavors.Type = 'FLAVOR_I_LAND_TRADE_ROUTE' AND Unit_AITypes.UnitAIType IN ('UNITAI_TRADE_UNIT')
--
OR Flavors.Type = 'FLAVOR_I_SEA_TRADE_ROUTE' AND Unit_AITypes.UnitAIType IN ('UNITAI_TRADE_UNIT')
--
--OR Flavors.Type = 'FLAVOR_I_TRADE_DESTINATION' AND Unit_AITypes.UnitAIType IN ()
--
OR Flavors.Type = 'FLAVOR_I_TRADE_ORIGIN' AND Unit_AITypes.UnitAIType IN ('UNITAI_TRADE_UNIT')
--
--OR Flavors.Type = 'FLAVOR_MILITARY_TRAINING' AND Unit_AITypes.UnitAIType IN ()
--
OR Flavors.Type = 'FLAVOR_MOBILE' AND (Unit_AITypes.UnitAIType IN ('UNITAI_FAST_ATTACK', 'UNITAI_RANGED') 
																AND Units.Moves >= 3)
--
OR Flavors.Type = 'FLAVOR_NAVAL' AND Unit_AITypes.UnitAIType IN ('UNITAI_ADMIRAL', 'UNITAI_ASSAULT_SEA', 'UNITAI_ATTACK_SEA', 'UNITAI_CARRIER_AIR', 'UNITAI_CARRIER_SEA', 
									'UNITAI_ESCORT_SEA', 'UNITAI_EXPLORE_SEA', 'UNITAI_MISSILE_AIR', 'UNITAI_MISSILE_CARRIER_SEA', 'UNITAI_PIRATE_SEA', 'UNITAI_RESERVE_SEA')
--
--OR Flavors.Type = 'FLAVOR_NAVAL_GROWTH' AND Unit_AITypes.UnitAIType IN ()
--
OR Flavors.Type = 'FLAVOR_NAVAL_RECON' AND Unit_AITypes.UnitAIType IN ('UNITAI_ESCORT_SEA', 'UNITAI_EXPLORE_SEA')
--
OR Flavors.Type = 'FLAVOR_NAVAL_TILE_IMPROVEMENT' AND Unit_AITypes.UnitAIType IN ('UNITAI_WORKER_SEA')
--
OR Flavors.Type = 'FLAVOR_NUKE' AND Unit_AITypes.UnitAIType IN ('UNITAI_ICBM', 'UNITAI_MISSILE_CARRIER_SEA')
--
OR Flavors.Type = 'FLAVOR_OFFENSE' AND Unit_AITypes.UnitAIType IN ('UNITAI_ASSAULT_SEA', 'UNITAI_ATTACK', 'UNITAI_ATTACK_AIR', 'UNITAI_CARRIER_AIR', 'UNITAI_CARRIER_SEA', 
									'UNITAI_CITY_BOMBARD', 'UNITAI_COUNTER', 'UNITAI_ESCORT_SEA', 'UNITAI_FAST_ATTACK', 'UNITAI_MISSILE_AIR', 'UNITAI_MISSILE_CARRIER_SEA', 
									'UNITAI_PARADROP', 'UNITAI_PIRATE_SEA', 'UNITAI_RANGED', 'UNITAI_ADMIRAL', 'UNITAI_GENERAL')
--
OR Flavors.Type = 'FLAVOR_PRODUCTION' AND Unit_AITypes.UnitAIType IN ('UNITAI_ENGINEER')
--
OR Flavors.Type = 'FLAVOR_RANGED' AND Unit_AITypes.UnitAIType IN ('UNITAI_ATTACK_AIR', 'UNITAI_ATTACK_SEA', 'UNITAI_CITY_BOMBARD', 'UNITAI_MISSILE_AIR', 'UNITAI_MISSILE_CARRIER_SEA', 
									'UNITAI_PARADROP', 'UNITAI_RANGED', 'UNITAI_ICBM')
--
OR Flavors.Type = 'FLAVOR_RECON' AND Unit_AITypes.UnitAIType IN ('UNITAI_EXPLORE')
--
OR Flavors.Type = 'FLAVOR_RELIGION' AND Unit_AITypes.UnitAIType IN ('UNITAI_INQUISITOR', 'UNITAI_MISSIONARY', 'UNITAI_PROPHET')
--
OR Flavors.Type = 'FLAVOR_SCIENCE' AND Unit_AITypes.UnitAIType IN ('UNITAI_SCIENTIST')
--
OR Flavors.Type = 'FLAVOR_SPACESHIP' AND Unit_AITypes.UnitAIType IN ('UNITAI_SPACESHIP_PART')
--
OR Flavors.Type = 'FLAVOR_TILE_IMPROVEMENT' AND Unit_AITypes.UnitAIType IN ('UNITAI_WORKER')
--
--OR Flavors.Type = 'FLAVOR_USE_NUKE' AND Unit_AITypes.UnitAIType IN ()
--
--OR Flavors.Type = 'FLAVOR_WATER_CONNECTION' AND Unit_AITypes.UnitAIType IN ()
--
--OR Flavors.Type = 'FLAVOR_WONDER' AND Unit_AITypes.UnitAIType IN ()
)
AND Unit_AITypes.UnitType = AnC_AllUN.UT
AND Units.Type = AnC_AllUN.UT
-- some FAKE to trigger Flavor's, where we have no Units
UNION ALL
SELECT 'FLAVOR_MILITARY_TRAINING' AS FT, 'UNIT_FAKE' AS UT, NULL AS UC, 'DOMAIN_LAND' AS Domain, 'UNITCOMBAT_FAKE' AS CC, 1 AS MP, 'UNITAI_FAKE' AS AIT, 'CIVILIZATION_FAKE' AS CT
UNION ALL
SELECT 'FLAVOR_MILITARY_TRAINING' AS FT, 'UNIT_FAKE' AS UT, NULL AS UC, 'DOMAIN_SEA' AS Domain, 'UNITCOMBAT_FAKE' AS CC, 1 AS MP, 'UNITAI_FAKE' AS AIT, 'CIVILIZATION_FAKE' AS CT
UNION ALL
SELECT 'FLAVOR_MILITARY_TRAINING' AS FT, 'UNIT_FAKE' AS UT, NULL AS UC, 'DOMAIN_AIR' AS Domain, 'UNITCOMBAT_FAKE' AS CC, 1 AS MP, 'UNITAI_FAKE' AS AIT, 'CIVILIZATION_FAKE' AS CT
UNION ALL
SELECT 'FLAVOR_MILITARY_TRAINING' AS FT, 'UNIT_FAKE' AS UT, NULL AS UC, 'DOMAIN_HOVER' AS Domain, 'UNITCOMBAT_FAKE' AS CC, 1 AS MP, 'UNITAI_FAKE' AS AIT, 'CIVILIZATION_FAKE' AS CT
UNION ALL
SELECT 'FLAVOR_PRODUCTION' AS FT, 'UNIT_FAKE' AS UT, NULL AS UC, 'DOMAIN_HOVER' AS Domain, 'UNITCOMBAT_FAKE' AS CC, 1 AS MP, 'UNITAI_FAKE' AS AIT, 'CIVILIZATION_FAKE' AS CT
------------------------------------------------------------------------------------------------------------------------------------------------------
ORDER BY FT;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2UnitAITypes END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Building_FreeUnits
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_Flavor2Building_FreeUnits' AS
SELECT Unit_Flavors.FlavorType AS FT, Building_FreeUnits.UnitType AS UT, Building_FreeUnits.BuildingType AS BT, sum(Unit_Flavors.Flavor) AS Flavor, Building_FreeUnits.NumUnits AS NumUnits
FROM Building_FreeUnits, Unit_Flavors
WHERE Building_FreeUnits.UnitType = Unit_Flavors.UnitType
GROUP BY FT, UT, BT;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_GreatPersons2Builds
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_GreatPersons2Builds' AS
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, Unit_Builds.BuildType AS YT, 'Unit_Builds.BuildType' AS FromTable
FROM Specialists, Units, Unit_Builds
WHERE Specialists.GreatPeopleUnitClass = Units.Class
AND Unit_Builds.UnitType = Units.Type
UNION ALL
--
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, Builds.ImprovementType AS YT, 'Builds.ImprovementType' AS FromTable
FROM Specialists, Units, Unit_Builds, Builds
WHERE Specialists.GreatPeopleUnitClass = Units.Class
AND Unit_Builds.UnitType = Units.Type
AND Builds.Type = Unit_Builds.BuildType
UNION ALL
-- there is no table for GP = GreatWorkType
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, GreatWorkClasses.Type AS YT, 'GreatWorkClasses.Type' AS FromTable
FROM Specialists, GreatWorkClasses, Units
WHERE Specialists.GreatPeopleUnitClass = Units.Class AND (Units.Class = 'UNITCLASS_ARTIST' AND GreatWorkClasses.Type = 'GREAT_WORK_ART'
OR Units.Class = 'UNITCLASS_MUSICIAN' AND GreatWorkClasses.Type = 'GREAT_WORK_MUSIC' 
OR Units.Class = 'UNITCLASS_WRITER' AND GreatWorkClasses.Type = 'GREAT_WORK_LITERATURE');


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Prepare AnC_GreatPersons2Yields
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_GreatPersons2YieldsT' ('UT' TEXT, 'UC' TEXT, 'ST' TEXT, 'YT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);

DELETE FROM 'AnC_GreatPersons2YieldsT';

INSERT INTO AnC_GreatPersons2YieldsT (UT, UC, ST, YT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- GreatPersons / GreatPeople
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT DISTINCT AnC_Flavor2UnitAITypes.UT AS UT, AnC_Flavor2UnitAITypes.UC AS UC, Specialists.Type AS ST, AnC_Flavor2UnitAITypes.UC AS YT, 1 AS Flavor,
'AnC_Flavor2UnitAITypes.UC' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes, Specialists
WHERE AnC_Flavor2UnitAITypes.UC = Specialists.GreatPeopleUnitClass
AND Specialists.GreatPeopleUnitClass NOT IN ('UNITCLASS_GREAT_GENERAL', 'UNITCLASS_GREAT_ADMIRAL')
UNION ALL
--
SELECT DISTINCT AnC_Flavor2UnitAITypes.UT AS UT, AnC_Flavor2UnitAITypes.UC AS UC, NULL AS ST, AnC_Flavor2UnitAITypes.UC AS YT, 0.5 AS Flavor,
'AnC_Flavor2UnitAITypes.UC' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2UnitAITypes
WHERE AnC_Flavor2UnitAITypes.UC IN ('UNITCLASS_GREAT_GENERAL', 'UNITCLASS_GREAT_ADMIRAL')
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, 'YIELD_GOLDEN_AGE_POINTS' AS YT, Units.GoldenAgeTurns AS Flavor, 
'Units.GoldenAgeTurns' AS FromTable, 'Vanilla' AS Mod
FROM Specialists, Units
WHERE Units.Class = Specialists.GreatPeopleUnitClass
AND Units.GoldenAgeTurns <> 0
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, 'YIELD_GOLD' AS YT, Units.BaseGold +NumGoldPerEra AS Flavor, 
'Units.BaseGold+NumGoldPerEra' AS FromTable, 'Vanilla' AS Mod
FROM Specialists, Units
WHERE Units.Class = Specialists.GreatPeopleUnitClass
AND Units.BaseGold <> 0
UNION ALL
--
/*
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, 'YIELD_GOLD' AS YT, Units.NumGoldPerEra AS Flavor, 
'Units.NumGoldPerEra' AS FromTable
FROM Specialists, Units
WHERE Units.Class = Specialists.GreatPeopleUnitClass
AND Units.NumGoldPerEra <> 0
UNION ALL
*/
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, 'YIELD_PRODUCTION' AS YT, Units.BaseHurry *HurryMultiplier AS Flavor, 
'Units.BaseHurry*HurryMultiplier' AS FromTable, 'Vanilla' AS Mod
FROM Specialists, Units
WHERE Units.Class = Specialists.GreatPeopleUnitClass
AND Units.BaseHurry <> 0 AND Units.HurryMultiplier <> 0
UNION ALL
--
/*
SELECT Units.Type AS UT, Units.Class AS UC, Specialists.Type AS ST, 'YIELD_PRODUCTION' AS YT, Units.HurryMultiplier AS Flavor, 
'Units.HurryMultiplier' AS FromTable
FROM Specialists, Units
WHERE Units.Class = Specialists.GreatPeopleUnitClass
AND Units.HurryMultiplier <> 0
UNION ALL
*/
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_GreatPersons2Builds.UT AS UT, AnC_GreatPersons2Builds.UC AS UC, AnC_GreatPersons2Builds.ST AS ST, AnC_GreatPersons2Builds.YT as YT, 1 AS Flavor, AnC_GreatPersons2Builds.FromTable, 'AnC' AS Mod
FROM AnC_GreatPersons2Builds
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_GreatPersons2Yields END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Builds2Improvements
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE VIEW IF NOT EXISTS 'AnC_Builds2Improvements' AS
SELECT Units.Type AS UT, Units.Class AS UC, Unit_Builds.BuildType AS BT, Builds.ImprovementType AS IT, Builds.PrereqTech AS PT
FROM Units, Unit_Builds, Builds
WHERE Unit_Builds.UnitType = Units.Type
AND Builds.Type = Unit_Builds.BuildType;


-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Executed = 1 WHERE File = 'AnC_QueryViews1A_STOCK.sql';
