-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Loaded = 1 WHERE File = 'AnC_QueryViews1C_STOCK.sql';
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_QueryViews1C_STOCK
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- Create Table & View AnC_Flavor2BuildingType/Building_Flavors (before Flavor 2 Resources or it will fail!)
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2BuildingType' ('FT' TEXT, 'BT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);
DELETE FROM AnC_Flavor2BuildingType;

-- create new Building_Flavors VIEW
DROP TABLE IF EXISTS 'Building_Flavors';

CREATE VIEW IF NOT EXISTS 'Building_Flavors' AS 
SELECT BT AS BuildingType, FT AS FlavorType, sum(Flavor) AS Flavor
FROM AnC_Flavor2BuildingType
WHERE Flavor >= 2.5
GROUP BY BT, FT
ORDER BY BT;


-- Trigger! Just in case a Mod inserts/updates/deletes Flavor's after AnC
CREATE TABLE IF NOT EXISTS 'Building_Flavors_OLD' ('BuildingType' TEXT, 'FlavorType' TEXT, 'Flavor' DECIMAL);
DELETE FROM Building_Flavors_OLD;

-- Insert new Flavor's, if not exists
CREATE TRIGGER IF NOT EXISTS 'AnC_Building_Flavors_INSERT' INSTEAD OF INSERT ON 'Building_Flavors'
BEGIN
INSERT INTO 'Building_Flavors_OLD' (BuildingType, FlavorType, Flavor)
SELECT new.BuildingType, new.FlavorType, new.Flavor; 

INSERT INTO 'AnC_Flavor2BuildingType' (FT, BT, Flavor, FromTable, Mod)
SELECT FlavorType AS FT, BuildingType as BT, Flavor, 'INSERT_afterAnC' AS FromTable, 'afterAnC' AS Mod
FROM Building_Flavors_OLD
WHERE Building_Flavors_OLD.BuildingType NOT IN (SELECT BT FROM AnC_Flavor2BuildingType);

DELETE FROM Building_Flavors_OLD;

INSERT OR REPLACE INTO 'AnC_DebugCheck' (File, Executed, Mod)
VALUES ('Building_Flavors_INSERT', 1, 'afterAnC');
END;

-- drop update of existing Flavor's
CREATE TRIGGER IF NOT EXISTS 'AnC_Building_Flavors_UPDATE' INSTEAD OF UPDATE ON 'Building_Flavors'
BEGIN
UPDATE 'Building_Flavors_OLD'
SET BuildingType = new.BuildingType, FlavorType = new.FlavorType, Flavor = new.Flavor
WHERE BuildingType = old.BuildingType; 

DELETE FROM Building_Flavors_OLD;

INSERT OR REPLACE INTO 'AnC_DebugCheck' (File, Executed, Mod)
VALUES ('Building_Flavors_UPDATE', 1, 'afterAnC');
END;

-- drop delete of existing Flavor's
CREATE TRIGGER IF NOT EXISTS 'AnC_Building_Flavors_DELETE' INSTEAD OF DELETE ON 'Building_Flavors'
BEGIN
DELETE FROM 'Building_Flavors_OLD'
WHERE BuildingType = old.BuildingType; 

INSERT OR REPLACE INTO 'AnC_DebugCheck' (File, Executed, Mod)
VALUES ('Building_Flavors_DELETE', 1, 'afterAnC');
END;


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Resources
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2ResourcesT' ('FT' TEXT, 'RT' TEXT, 'Flavor' DECIMAL, 'RU' INTEGER, 'FromTable' TEXT, 'CT' TEXT);

DELETE FROM AnC_Flavor2ResourcesT;

INSERT INTO AnC_Flavor2ResourcesT (FT, RT, Flavor, RU, FromTable, CT)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Flavor2Units - Unit_ResourceQuantityRequirements (Flavor2Units)
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2UnitAITypes.FT AS FT, Unit_ResourceQuantityRequirements.ResourceType AS RT, 
(SELECT CASE 
WHEN sum(Unit_ResourceQuantityRequirements.Cost) BETWEEN 1 AND 3 THEN 30 
WHEN sum(Unit_ResourceQuantityRequirements.Cost) BETWEEN 4 AND 6 THEN 45
WHEN sum(Unit_ResourceQuantityRequirements.Cost) BETWEEN 7 AND 9 THEN 60
WHEN sum(Unit_ResourceQuantityRequirements.Cost) BETWEEN 10 AND 12 THEN 75
WHEN sum(Unit_ResourceQuantityRequirements.Cost) >= 13 THEN 100
END) AS Flavor, Resources.ResourceUsage AS RU,
'Flavor2Units' AS FromTable, (SELECT CASE WHEN Resources.CivilizationType NOT NULL THEN Resources.CivilizationType ELSE 'CIVILIZATION_ALL' END) AS CT
FROM Unit_ResourceQuantityRequirements,  AnC_Flavor2UnitAITypes, Resources
WHERE Unit_ResourceQuantityRequirements.UnitType = AnC_Flavor2UnitAITypes.UT
AND Unit_ResourceQuantityRequirements.ResourceType = Resources.Type
GROUP BY FT, RT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Flavor2Yield
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Resource_YieldChanges.ResourceType AS RT, Resource_YieldChanges.Yield *AnC_Flavor2Yields.Flavor AS Flavor, Resources.ResourceUsage AS RU,
'Flavor2Yield' AS FromTable, (SELECT CASE WHEN Resources.CivilizationType NOT NULL THEN Resources.CivilizationType ELSE 'CIVILIZATION_ALL' END) AS CT
FROM Resources, AnC_Flavor2Yields, Resource_YieldChanges
WHERE Resource_YieldChanges.YieldType = AnC_Flavor2Yields.YT
AND Resource_YieldChanges.ResourceType = Resources.Type
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Flavor4Special 
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT Flavors.Type AS FT, Resources.Type AS RT, 50 AS Flavor, Resources.ResourceUsage AS RU, 'Flavor4Special' AS FromTable, 
(SELECT CASE WHEN Resources.CivilizationType NOT NULL THEN Resources.CivilizationType ELSE 'CIVILIZATION_ALL' END) AS CT
FROM Resources, Flavors
WHERE (Flavors.Type IN ('FLAVOR_CULTURE', 'FLAVOR_ARCHAEOLOGY') AND Resources.Type IN ('RESOURCE_ARTIFACTS', 'RESOURCE_HIDDEN_ARTIFACTS'))
GROUP BY FT, RT
UNION ALL
-- 
SELECT Flavors.Type AS FT, Resources.Type AS RT, 10 AS Flavor, Resources.ResourceUsage AS RU, 'Flavor4Mag' AS FromTable, 
(SELECT CASE WHEN Resources.CivilizationType NOT NULL THEN Resources.CivilizationType ELSE 'CIVILIZATION_ALL' END) AS CT
FROM Resources, Flavors
WHERE (Flavors.Type IN ('FLAVOR_CULTURE', 'FLAVOR_GOLD', 'FLAVOR_GROWTH') AND Resources.Type IN ('RESOURCE_MAGISTRATES'))
GROUP BY FT, RT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Flavor4Happines
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Resources.Type AS RT, Resources.Happiness *AnC_Flavor2Yields.Flavor AS Flavor, Resources.ResourceUsage AS RU, 
'Flavor4Happines' AS FromTable, (SELECT CASE WHEN Resources.CivilizationType NOT NULL THEN Resources.CivilizationType ELSE 'CIVILIZATION_ALL' END) AS CT
FROM Resources, AnC_Flavor2Yields
WHERE Resources.Happiness >= 1 AND AnC_Flavor2Yields.YT = 'Happiness'
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Flavor4Resources2Wonder
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Resources.Type AS RT, Resources.WonderProductionMod *AnC_Flavor2Yields.Flavor AS Flavor, Resources.ResourceUsage AS RU, 
'Flavor2Wonder' AS FromTable, (SELECT CASE WHEN Resources.CivilizationType NOT NULL THEN Resources.CivilizationType ELSE 'CIVILIZATION_ALL' END) AS CT
FROM Resources, AnC_Flavor2Yields
WHERE Resources.WonderProductionMod >= 1 AND AnC_Flavor2Yields.YT = 'WonderProductionModifier'
------------------------------------------------------------------------------------------------------------------------------------------------------
ORDER BY FT;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Resources END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2GoodyHuts
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2GoodyHutsT' ('FT' TEXT, 'GT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);

DELETE FROM AnC_Flavor2GoodyHutsT;

INSERT INTO AnC_Flavor2GoodyHutsT (FT, GT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- GoodyHuts
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, GoodyHuts.Type AS GT, GoodyHuts.Population *AnC_Flavor2Yields.Flavor AS Flavor,
'GoodyHuts.Population' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, GoodyHuts
WHERE GoodyHuts.Population <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_POPULATION'
UNION ALL
--
SELECT AnC_Flavor2Yields.FT AS FT, GoodyHuts.Type AS GT, GoodyHuts.Culture *AnC_Flavor2Yields.Flavor AS Flavor,
'GoodyHuts.Culture' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, GoodyHuts
WHERE GoodyHuts.Culture <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
--
SELECT AnC_Flavor2Yields.FT AS FT, GoodyHuts.Type AS GT, GoodyHuts.Tech *AnC_Flavor2Yields.Flavor *(SELECT TableMul FROM AnC_Flavor2Yields WHERE YT = 'FreeTechs') AS Flavor,
'GoodyHuts.Tech' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, GoodyHuts
WHERE GoodyHuts.Tech <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_SCIENCE'
UNION ALL
--
SELECT AnC_Flavor2Yields.FT AS FT, GoodyHuts.Type AS GT, GoodyHuts.Gold *AnC_Flavor2Yields.Flavor *0.25 AS Flavor,
'GoodyHuts.Gold' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, GoodyHuts
WHERE GoodyHuts.Gold <> 0 AND AnC_Flavor2Yields.YT = 'YIELD_GOLD'
UNION ALL
--
SELECT AnC_Flavor2Yields.FT AS FT, GoodyHuts.Type AS GT, GoodyHuts.Experience *AnC_Flavor2Yields.Flavor AS Flavor,
'GoodyHuts.Experience' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, GoodyHuts
WHERE GoodyHuts.Experience <> 0 AND AnC_Flavor2Yields.YT = 'FreeExperience'
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2GoodyHuts END
------------------------------------------------------------------------------------------------------------------------------------------------------


------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Improvement_Yields
------------------------------------------------------------------------------------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS 'AnC_Flavor2Improvement_YieldsT' ('FT' TEXT, 'IT' TEXT, 'Flavor' DECIMAL, 'FromTable' TEXT, 'Mod' TEXT);

DELETE FROM AnC_Flavor2Improvement_YieldsT;

INSERT INTO AnC_Flavor2Improvement_YieldsT (FT, IT, Flavor, FromTable, Mod)
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvements
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Improvements.Type AS IT, Improvements.BarbarianCamp *AnC_Flavor2Yields.Flavor AS Flavor,
'Improvements.BarbarianCamp' AS FromTable, 'Vanilla' AS Mod
FROM Improvements, AnC_Flavor2Yields
WHERE Improvements.BarbarianCamp = 1 
AND AnC_Flavor2Yields.YT = 'BarbarianCamp'
UNION ALL
--
SELECT AnC_Flavor2Yields.FT AS FT, Improvements.Type AS IT, Improvements.CultureAdjacentSameType *AnC_Flavor2Yields.Flavor *0.5 AS Flavor,
'Improvements.CultureAdjacentSameType' AS FromTable, 'Vanilla' AS Mod
FROM Improvements, AnC_Flavor2Yields
WHERE Improvements.CultureAdjacentSameType > 0
AND AnC_Flavor2Yields.YT = 'YIELD_CULTURE'
UNION ALL
--
SELECT AnC_Flavor2Yields.FT AS FT, Improvements.Type AS IT, Improvements.DefenseModifier *AnC_Flavor2Yields.Flavor AS Flavor,
'Improvements.DefenseModifier' AS FromTable, 'Vanilla' AS Mod
FROM Improvements, AnC_Flavor2Yields
WHERE Improvements.DefenseModifier <> 0 
AND AnC_Flavor2Yields.YT = 'DefenseModifier'
UNION ALL
--
/*
SELECT AnC_Flavor2Yields.FT AS FT, Improvements.Type AS IT, Improvements.NearbyEnemyDamage *AnC_Flavor2Yields.Flavor AS Flavor,
'Improvements.NearbyEnemyDamage' AS FromTable, 'Vanilla' AS Mod
FROM Improvements, AnC_Flavor2Yields
WHERE Improvements.NearbyEnemyDamage <> 0 
AND AnC_Flavor2Yields.YT = 'NearbyEnemyDamage'
UNION ALL
*/
--
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_Yields 
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT, Improvement_Yields.ImprovementType AS IT, sum(Improvement_Yields.Yield) 
*AnC_Flavor2Yields.Flavor /count(Improvement_Yields.YieldType) AS Flavor, 'Improvement_Yields' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Improvement_Yields
WHERE Improvement_Yields.YieldType = AnC_Flavor2Yields.YT
GROUP BY FT, IT
UNION ALL
-- 
SELECT (SELECT CASE WHEN Improvements.Water = 1 THEN 'FLAVOR_NAVAL_TILE_IMPROVEMENT' ELSE 'FLAVOR_TILE_IMPROVEMENT' END) AS FT, Improvement_Yields.ImprovementType AS IT, 
sum(Improvement_Yields.Yield) *5 AS Flavor, 'Improvement_Yields-FLAVOR_TILE_IMPROVEMENT' AS FromTable, 'Vanilla' AS Mod
FROM Improvement_Yields, Improvements
WHERE Improvement_Yields.Yield <> 0 AND Improvement_Yields.ImprovementType = Improvements.Type
GROUP BY IT
UNION ALL
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_RouteYieldChanges 
------------------------------------------------------------------------------------------------------------------------------------------------------
/*
SELECT AnC_Flavor2Yields.FT, Improvement_RouteYieldChanges.ImprovementType AS IT, sum(Improvement_RouteYieldChanges.Yield) 
*AnC_Flavor2Yields.Flavor /count(Improvement_RouteYieldChanges.RouteType) *0.25 AS Flavor,
'Improvement_RouteYieldChanges' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Improvement_RouteYieldChanges
WHERE Improvement_RouteYieldChanges.Yield <> 0 AND Improvement_RouteYieldChanges.YieldType = AnC_Flavor2Yields.YT
GROUP BY FT, IT
UNION ALL
*/
------------------------------------------------------------------------------------------------------------------------------------------------------
-- Improvement_ResourceType_Yields - AnC_Flavor2Yields
------------------------------------------------------------------------------------------------------------------------------------------------------
SELECT AnC_Flavor2Yields.FT AS FT, Improvement_ResourceType_Yields.ImprovementType AS IT, sum(Improvement_ResourceType_Yields.Yield) 
*AnC_Flavor2Yields.Flavor /count(Improvement_ResourceType_Yields.YieldType) *0.5 AS Flavor,
'Improvement_ResourceType_Yields - AnC_Flavor2Yields' AS FromTable, 'Vanilla' AS Mod
FROM AnC_Flavor2Yields, Improvement_ResourceType_Yields
WHERE Improvement_ResourceType_Yields.Yield <> 0 AND Improvement_ResourceType_Yields.YieldType = AnC_Flavor2Yields.YT
GROUP BY FT, IT
UNION ALL
--
SELECT (SELECT CASE WHEN Improvements.Water = 1 THEN 'FLAVOR_NAVAL_TILE_IMPROVEMENT' ELSE 'FLAVOR_TILE_IMPROVEMENT' END) AS FT, 
Improvement_ResourceType_Yields.ImprovementType AS IT, sum(Improvement_ResourceType_Yields.Yield) /count(Improvement_ResourceType_Yields.YieldType) *5 AS Flavor,
'Improvement_ResourceType_Yields-FLAVOR_TILE_IMPROVEMENT' AS FromTable, 'Vanilla' AS Mod
FROM Improvement_ResourceType_Yields, Improvements
WHERE Improvement_ResourceType_Yields.Yield <> 0 AND Improvement_ResourceType_Yields.ImprovementType = Improvements.Type
GROUP BY IT
------------------------------------------------------------------------------------------------------------------------------------------------------
;
------------------------------------------------------------------------------------------------------------------------------------------------------
-- AnC_Flavor2Improvement_Yields END
------------------------------------------------------------------------------------------------------------------------------------------------------


-- AnC DebugCheck
UPDATE AnC_DebugCheck SET Executed = 1 WHERE File = 'AnC_QueryViews1C_STOCK.sql';